*Change the folders
* The folder $data must contain the file "data.dta".
* the results will be saved in the folder $ results.
global data "C:\Users\Blaise\Dropbox\COUNTERFACTUAL\Replication files\Data\"
global results "C:\Users\Blaise\Dropbox\COUNTERFACTUAL\Replication files\Results\"

*Mata commands
*logistic distribution
cap mata mata drop logisticcdf()
mata real colvector logisticcdf(real colvector x) return(1:/(1:+exp(-x)))

*objective function of the weighted logit estimator
cap mata mata drop lnwlogit()
mata void lnwlogit(real scalar todo, real rowvector p, real matrix x, real colvector y, real colvector w, real colvector lnf, real matrix S, real matrix H)
{
	real colvector prob
	prob=logisticcdf(x*p')
	lnf=w:*log(y:*prob:+(1:-y):*(1:-prob))
	if (todo >= 1) {
		S=w:*(x:*(y-prob))
		if (todo==2) {
			H=-(w:*x:*prob:*(1:-prob))'x
		}
	}
}

cap mata mata drop intlogit()
mata colvector intlogit(real colvector yt, real matrix xt, real colvector wt){
	S = optimize_init()
	optimize_init_conv_warning(S,"off")
	optimize_init_evaluator(S, &lnwlogit())
	optimize_init_evaluatortype(S, "gf2")
	optimize_init_conv_maxiter(S, 100)
	optimize_init_verbose(S, 0)
	optimize_init_tracelevel(S, "none")
	optimize_init_params(S,((invsym((xt:*wt)'xt)*(xt:*wt)'yt))')
	optimize_init_argument(S, 1, xt)
	optimize_init_argument(S, 2, yt)
	optimize_init_argument(S, 3, wt)
	ret = _optimize(S)
	return(optimize_result_params(S)')
}	

cap mata mata drop call_cqr()
mata numeric matrix call_cqr(string scalar group1, string scalar group2, real matrix RQ_deco_C1, real matrix RQ_deco_C2)
{
	z10=st_data(.,tokens("union smsa partt nonwhite grade1to4 grade5to6 grade7to8 grade9 grade10 grade11 highschool somecollege college egrade1to4 egrade5to6 egrade7to8 egrade9 egrade10 egrade11 ehighschool esomecollege ecollege exper exper2 exper3 exper4 oc2 oc3 ind2 ind3 ind4 ind5 ind6 ind7 ind8 ind9 ind10 ind11 ind12 ind13 ind14 ind15 ind16 ind17 ind18 ind19"),group1)
	z10=(J(rows(z10),1,1),z10)
	z20=st_data(.,tokens("union smsa partt nonwhite grade1to4 grade5to6 grade7to8 grade9 grade10 grade11 highschool somecollege college egrade1to4 egrade5to6 egrade7to8 egrade9 egrade10 egrade11 ehighschool esomecollege ecollege exper exper2 exper3 exper4 oc2 oc3 ind2 ind3 ind4 ind5 ind6 ind7 ind8 ind9 ind10 ind11 ind12 ind13 ind14 ind15 ind16 ind17 ind18 ind19"),group2)
	z20=(J(rows(z20),1,1),z20)
	w10=st_data(.,"eweight",group1)
	w20=st_data(.,"eweight",group2)
	y10=st_data(.,"logwc",group1)
	y20=st_data(.,"logwc",group2)
	RQ_deco_QaN=(20..980)'/1000
	RQ_deco_11=exp(cross(z10',RQ_deco_C1))'
	RQ_deco_22=exp(cross(z20',RQ_deco_C2))'
	RQ_deco_NqA=cols(RQ_deco_C1)
	q1979=mm_quantile(y10,w10,RQ_deco_QaN)
	q1988=mm_quantile(y20,w20,RQ_deco_QaN)
	qq1=mm_quantile(vec(RQ_deco_11'),vec(w10*J(1,RQ_deco_NqA,1)),RQ_deco_QaN)
	qq1=rowmax((qq1,J(rows(qq1),1,3)))
	qq2=mm_quantile(vec(RQ_deco_22'),vec(w20*J(1,RQ_deco_NqA,1)),RQ_deco_QaN)
	qq2=rowmax((qq2,J(rows(qq1),1,2.2085)))
	//counterfactual distribution with minimum wage as in 1979
	qqc1=mm_quantile(vec(RQ_deco_22'),vec(w20*J(1,RQ_deco_NqA,1)),RQ_deco_QaN)
	qqc1=rowmax((qqc1,J(rows(qqc1),1,3)))
	//counterfactual distribution with minimum wage and union as in 1979
	unions=logisticcdf((z20[.,1],z20[.,3..cols(z20)])*intlogit(z10[.,2],(z10[.,1],z10[.,3..cols(z10)]),w10))
	z20c=z20\z20
	z20c[1..rows(z20),2]=J(rows(z20),1,0)
	z20c[(rows(z20)+1)..rows(z20c),2]=J(rows(z20),1,1)
	w20c=(w20:*(1:-unions))\(w20:*unions)
	RQ_deco_c2=exp(cross(z20c',RQ_deco_C2))'
	qqc2=mm_quantile(vec(RQ_deco_c2'),vec(w20c*J(1,RQ_deco_NqA,1)),RQ_deco_QaN)
	qqc2=rowmax((qqc2,J(rows(qqc2),1,3)))
	//counterfactual distribution with minimum wage and all characteristics as in 1979
	temp=exp(cross(z10',RQ_deco_C2))'
	qqc3=mm_quantile(vec(temp'),vec(w10*J(1,RQ_deco_NqA,1)),RQ_deco_QaN)
	qqc3=rowmax((qqc3,J(rows(qqc3),1,3)))
	results=q1979,q1988,log(qq1),log(qq2),log(qqc1),log(qqc2),log(qqc3)
	return(results)
}

*Point estimates
use "${results}coefinR.dta", clear
mata
a=st_data(.,.)
cqr01=a[.,1..100]
cqr02=a[.,101..200]
cqr11=a[.,201..300]
cqr12=a[.,301..400]
end
use "${data}data.dta", clear
mata
res_cqr=call_cqr("select10","select20", cqr01, cqr02)
fh=fopen("${results}men_cqr","rw")
fputmatrix(fh,res_cqr)
fclose(fh)
res_cqr=call_cqr("select11","select21", cqr11, cqr12)
fh=fopen("${results}women_cqr","rw")
fputmatrix(fh,res_cqr)
fclose(fh)
end
*Bootstrap
forvalues i=1/100{
use "${results}coefinR`i'.dta", clear
mata a=st_data(.,.)
mata cqr01=a[.,1..100]
mata cqr02=a[.,101..200]
mata cqr11=a[.,201..300]
mata cqr12=a[.,301..400]
use "${data}boot`i'.dta", clear
mata res_cqr=call_cqr("select10","select20", cqr01, cqr02)
mata fh=fopen("${results}boot_men_cqr","a")
mata fputmatrix(fh,res_cqr)
mata fclose(fh)
mata res_cqr=call_cqr("select11","select21", cqr11, cqr12)
mata fh=fopen("${results}boot_women_cqr","a")
mata fputmatrix(fh,res_cqr)
mata fclose(fh)
}
