*Change the folders
* The folder $data must contain the file "data.dta".
* the results will be saved in the folder $ results.
global data "C:\Users\Blaise\Dropbox\COUNTERFACTUAL\Replication files\Data\"
global results "C:\Users\Blaise\Dropbox\COUNTERFACTUAL\Replication files\Results\"

*Functions for estimation
*Mata, logistic distribution
cap mata mata drop logisticcdf()
mata real colvector logisticcdf(real colvector x) return(1:/(1:+exp(-x)))

*Mata, objective function of the weighted logit estimator
cap mata mata drop lnwlogit()
mata void lnwlogit(real scalar todo, real rowvector p, real matrix x, real colvector y, real colvector w, real colvector lnf, real matrix S, real matrix H)
{
	real colvector prob
	prob=logisticcdf(x*p')
	lnf=w:*log(y:*prob:+(1:-y):*(1:-prob))
	if (todo >= 1) {
		S=w:*(x:*(y-prob))
		if (todo==2) {
			H=-(w:*x:*prob:*(1:-prob))'x
		}
	}
}

*Mata, objective function of the weighted probit estimator
cap mata mata drop lnwprobit()
mata void lnwprobit(real scalar todo, real rowvector p, real matrix x, real colvector y, real colvector w, real colvector lnf, real matrix S, real matrix H)
{
	real colvector prob
	temp1=x*p'
	prob=normal(temp1)
	temp=y:*prob:+(1:-y):*(1:-prob)
	lnf=w:*log(temp)
	if (todo >= 1) {
		prob=rowmax((rowmin((prob,J(rows(prob),1,0.999))),J(rows(prob),1,0.001)))
		S=w:*x:*(normalden(temp1):*(y:-prob):/(prob:*(1:-prob)))
		if (todo==2) {
			H=-(w:*x:*normalden(temp1):^2:/prob:/(1:-prob))'x
		}
	}
}

*Mata, objective function of the weighted probit estimator
cap mata mata drop lnwcauchit()
mata void lnwcauchit(real scalar todo, real rowvector p, real matrix x, real colvector y, real colvector w, real colvector lnf, real matrix S, real matrix H)
{
	real colvector prob
	temp1=x*p'
	prob=1:-ttail(1,temp1)
	temp=y:*prob:+(1:-y):*(1:-prob)
	lnf=w:*log(temp)
	if (todo >= 1) {
		prob=rowmax((rowmin((prob,J(rows(prob),1,0.999))),J(rows(prob),1,0.001)))
		S=w:*x:*(tden(1,temp1):*(y:-prob):/(prob:*(1:-prob)))
		if (todo==2) {
			H=-(w:*x:*tden(1,temp1):^2:/prob:/(1:-prob))'x
		}
	}
}

cap mata mata drop intlogit()
mata colvector intlogit(real colvector yt, real matrix xt, real colvector wt){
	S = optimize_init()
	optimize_init_conv_warning(S,"off")
	optimize_init_evaluator(S, &lnwlogit())
	optimize_init_evaluatortype(S, "gf2")
	optimize_init_conv_maxiter(S, 100)
	optimize_init_verbose(S, 0)
	optimize_init_tracelevel(S, "none")
	optimize_init_params(S,((invsym((xt:*wt)'xt)*(xt:*wt)'yt))')
	optimize_init_argument(S, 1, xt)
	optimize_init_argument(S, 2, yt)
	optimize_init_argument(S, 3, wt)
	ret = _optimize(S)
	return(optimize_result_params(S)')
}	

cap mata mata drop intprobit()
mata colvector intprobit(real colvector yt, real matrix xt, real colvector wt){
	S = optimize_init()
	optimize_init_evaluator(S, &lnwprobit())
	optimize_init_evaluatortype(S, "gf2")
	optimize_init_conv_maxiter(S, 100)
	optimize_init_verbose(S, 0)
	optimize_init_tracelevel(S, "none")
	optimize_init_params(S,((invsym((xt:*wt)'xt)*(xt:*wt)'yt))')
	optimize_init_argument(S, 1, xt)
	optimize_init_argument(S, 2, yt)
	optimize_init_argument(S, 3, wt)
	ret = _optimize(S)
	return(optimize_result_params(S)')
}	

cap mata mata drop intcauchit()
mata colvector intcauchit(real colvector yt, real matrix xt, real colvector wt){
	S = optimize_init()
	optimize_init_evaluator(S, &lnwcauchit())
	optimize_init_evaluatortype(S, "gf2")
	optimize_init_conv_maxiter(S, 100)
	optimize_init_verbose(S, 0)
	optimize_init_tracelevel(S, "none")
	optimize_init_params(S,((invsym((xt:*wt)'xt)*(xt:*wt)'yt))')
	optimize_init_argument(S, 1, xt)
	optimize_init_argument(S, 2, yt)
	optimize_init_argument(S, 3, wt)
	optimize_init_conv_ignorenrtol(S, "on")
	ret = _optimize(S)
	return(optimize_result_params(S)')
}	

cap mata mata drop binary_reg()
mata colvector binary_reg(string scalar touse, real colvector yt, string scalar reg, string scalar weight, string scalar method,idx){
	st_store(.,idx,touse,yt)
	if(method=="logit") stata("logit "+idx+" "+reg+" [pweight="+weight+"] if "+touse+"==1, asis iterate(100)",1)
	if(method=="probit") stata("probit "+idx+" "+reg+" [pweight="+weight+"] if "+touse+"==1, asis iterate(100)",1)
	if(method=="lpm") stata("regress "+idx+" "+reg+" [pweight="+weight+"] if "+touse+"==1, iterate(100)",1)
	if(method=="cauchit") stata("gologit2 "+idx+" "+reg+" [pweight="+weight+"] if "+touse+"==1, link(ca) iterate(100) mlstart",1)
	if(method=="loglog") stata("cloglog "+idx+" "+reg+" [pweight="+weight+"] if "+touse+"==1, asis iterate(100)",1)
	temp=st_matrix("e(b)")'
	return(temp)
}

cap mata mata drop fitted_prob()
mata colvector fitted_prob(real matrix xt, real colvector coef, string scalar method){
	if(method=="logit") temp=logisticcdf(xt*coef)
	if(method=="probit") temp=normal(xt*coef)
	if(method=="lpm") temp=xt*coef
	if(method=="cauchit") temp=1:-ttail(1,xt*coef)
	if(method=="loglog") temp=1:-exp(-exp(xt*coef))
	return(temp)
}

cap mata mata drop wdist1()
version 9.2
mata real wdist1(y,w,ev){
d=J(cols(ev),1,.)
for(i=1; i<=cols(ev);i++) d[i]=mean(y:<=ev[i],w)
return(d)
}

cap mata mata drop dist_quant()
version 9.2
mata real dist_quant(ev,d,q)
{
	out=J(rows(q),1,0)
	a=1
	for(i=1; i<=rows(q); i++){
		while(d[a]<q[i]) a=a+1
		out[i]=ev[a]
	}
	return(out)
}

cap mata mata drop cal_dr()
mata numeric matrix cal_dr(string scalar group0, string scalar group1, string scalar method, real colvector ys)
{
	reg="union smsa partt nonwhite grade1to4 grade5to6 grade7to8 grade9 grade10 grade11 highschool somecollege college egrade1to4 egrade5to6 egrade7to8 egrade9 egrade10 egrade11 ehighschool esomecollege ecollege exper exper2 exper3 exper4 oc2 oc3 ind2 ind3 ind4 ind5 ind6 ind7 ind8 ind9 ind10 ind11 ind12 ind13 ind14 ind15 ind16 ind17 ind18 ind19"
	reg1="smsa partt nonwhite grade1to4 grade5to6 grade7to8 grade9 grade10 grade11 highschool somecollege college egrade1to4 egrade5to6 egrade7to8 egrade9 egrade10 egrade11 ehighschool esomecollege ecollege exper exper2 exper3 exper4 oc2 oc3 ind2 ind3 ind4 ind5 ind6 ind7 ind8 ind9 ind10 ind11 ind12 ind13 ind14 ind15 ind16 ind17 ind18 ind19"
	wei="eweight"
	dep="wage"
	y0=log(st_data(.,dep,group0))
	y1=log(st_data(.,dep,group1))
	z0=st_data(.,reg,group0)
	z0=(z0,J(rows(z0),1,1))
	z1=st_data(.,reg,group1)
	z1=(z1,J(rows(z1),1,1))
	w0=st_data(.,wei,group0)
	w1=st_data(.,wei,group1)
	ys=mm_quantile((y0\y1),(w0\w1),(10..990)/1000)'
	nys=rows(ys)
	temp=st_addvar("byte", idx=st_tempname())
	//Estimation of the re-weighting
	fit0=binary_reg(group0, y0:<=log(3)+0.000001, reg, wei, method,idx)
	prob0=fitted_prob(z1,fit0,method)
	fit1=binary_reg(group1, y1:<=log(3)+0.000001, reg, wei, method,idx)
	prob1=fitted_prob(z1,fit1,method)
	phi=prob1:/prob0
	//estimation of the conditional distribution
	coef0=J(cols(z0),colsum(ys:<=3),0)
	i=1
	while(ys[i]<=log(3)+0.00001){
		if (i>1 & ys[i]==ys[max(1\(i-1))]) coef0[.,i]=coef0[.,i-1]
		else coef0[.,i]=binary_reg(group0, y0:<=ys[i], reg, wei, method, idx)
		i=i+1
	}
	coef1=J(cols(z1),nys,0)
	while(i<=nys){
		if (i>cols(coef0) & ys[i]==ys[i-1]) coef1[.,i]=coef1[.,i-1]
		else coef1[.,i]=binary_reg(group1, y1:<=ys[i], reg, wei, method, idx)
		i=i+1
	}
	//observed quantiles in 1988 and 1979
	q0=dist_quant(ys,wdist1(y0,w0,ys'),(20..980)'/1000)
	q1=dist_quant(ys,wdist1(y1,w1,ys'),(20..980)'/1000)
	//counterfactual distribution with minimum wage as in 1979
	pred=J(0,1,0)
	i=1
	while(ys[i]<=log(3)+0.00001){
		if (i>1 & ys[i]==ys[max(1\(i-1))]) pred=pred\pred[i-1]
		else{
			temp=fitted_prob(z1,coef0[.,i],method)
			temp=temp:*phi
			pred=pred\mean(temp,w1)
		}
		i=i+1
	}
	pred=pred\wdist1(y1,w1,ys[i..nys]')
	qcounter1=mm_quantile(ys,pred-(0\pred[1..(rows(pred)-1)]),((20..980)/1000)/max(pred))'
	//counterfactual distribution with minimum wage and union as in 1979
	temp=binary_reg(group0, z0[.,1], reg1, wei, method, idx)
	unions=fitted_prob(z1[.,2..cols(z1)],temp,method)
	z1c=z1\z1
	z1c[1..rows(z1),1]=J(rows(z1),1,0)
	z1c[(rows(z1)+1)..rows(z1c),1]=J(rows(z1),1,1)
	w1c=(w1:*(1:-unions))\(w1:*unions)
	prob0=fitted_prob(z1c,fit0,method)
	prob1=fitted_prob(z1c,fit1,method)
	phic=prob1:/prob0
	pred=J(0,1,0)
	i=1
	while(ys[i]<=log(3)+0.00001){
		if (i>1 & ys[i]==ys[max(1\(i-1))]) pred=pred\pred[i-1]
		else{
			temp=fitted_prob(z1c,coef0[.,i],method)
			temp=temp:*phic
			pred=pred\mean(temp,w1c)
		}
		i=i+1
	}
	while(i<=nys){
		if (i>cols(coef0) & ys[i]==ys[i-1]) pred=pred\pred[i-1]
		else{
			temp=fitted_prob(z1c,coef1[.,i],method)
			pred=pred\mean(temp,w1c)
		}
		i=i+1
	}
	qcounter2=mm_quantile(ys,pred-(0\pred[1..(rows(pred)-1)]),((20..980)/1000)/max(pred))'
	//counterfactual distribution with minimum wage and all characteristics as in 1979
	prob0=fitted_prob(z0,fit0,method)
	prob1=fitted_prob(z0,fit1,method)
	phic=prob1:/prob0
	pred=J(0,1,0)
	i=1
	while(ys[i]<=log(3)+0.00001){
		if (i>1 & ys[i]==ys[max(1\(i-1))]) pred=pred\pred[i-1]
		else{
			temp=fitted_prob(z0,coef0[.,i],method)
			temp=temp:*phic
			pred=pred\mean(temp,w0)
		}	
		i=i+1
	}
	while(i<=nys){
		if (i>cols(coef0) & ys[i]==ys[i-1]) pred=pred\pred[i-1]
		else{
			temp=fitted_prob(z0,coef1[.,i],method)
			pred=pred\mean(temp,w0)
		}
		i=i+1
	}
	qcounter3=mm_quantile(ys,pred-(0\pred[1..(rows(pred)-1)]),((20..980)/1000)/max(pred))'
	results=q0,q1,qcounter1,qcounter2,qcounter3
	return(results)
}

*Inverted order
cap mata mata drop inv_logit()
mata numeric matrix inv_logit(string scalar group0, string scalar group1)
{
	y10=st_data(.,"wage",group0)
	y20=st_data(.,"wage",group1)
	z10=st_data(.,tokens("union smsa partt nonwhite grade1to4 grade5to6 grade7to8 grade9 grade10 grade11 highschool somecollege college egrade1to4 egrade5to6 egrade7to8 egrade9 egrade10 egrade11 ehighschool esomecollege ecollege exper exper2 exper3 exper4 oc2 oc3 ind2 ind3 ind4 ind5 ind6 ind7 ind8 ind9 ind10 ind11 ind12 ind13 ind14 ind15 ind16 ind17 ind18 ind19"),group0)
	z10=(z10,J(rows(z10),1,1))
	z20=st_data(.,tokens("union smsa partt nonwhite grade1to4 grade5to6 grade7to8 grade9 grade10 grade11 highschool somecollege college egrade1to4 egrade5to6 egrade7to8 egrade9 egrade10 egrade11 ehighschool esomecollege ecollege exper exper2 exper3 exper4 oc2 oc3 ind2 ind3 ind4 ind5 ind6 ind7 ind8 ind9 ind10 ind11 ind12 ind13 ind14 ind15 ind16 ind17 ind18 ind19"),group1)
	z20=(z20,J(rows(z20),1,1))
	w10=st_data(.,"eweight",group0)
	w20=st_data(.,"eweight",group1)
	taus=(10..990)/1000
	ys=mm_quantile((y10\y20),(w10\w20),taus)'
	nys=rows(ys)
	//estimation of the conditional distribution
	coef10=J(cols(z10),colsum(ys:<=3),0)
	i=1
	while(ys[i]<=3){
		if (i>1 & ys[i]==ys[max(1\(i-1))]) coef10[.,i]=coef10[.,i-1]
		else coef10[.,i]=intlogit(y10:<=ys[i],z10,w10)
		i=i+1
	}
	coef20=J(cols(z20),nys,0)
	i=1
	while(i<=nys){
		if (i>1 & ys[i]==ys[max(1\(i-1))]) coef20[.,i]=coef20[.,i-1]
		else coef20[.,i]=intlogit(y20:<=ys[i],z20,w20)
		i=i+1
	}
	//observed quantiles in 1988 and 1979
	q1979=dist_quant(ys,wdist1(y10,w10,ys'),(20..980)'/1000)
	q1988=dist_quant(ys,wdist1(y20,w20,ys'),(20..980)'/1000)
	//counterfactual distribution with characteristics as in 1979
	w10c=w10:*(z10[.,1]:*mean(z20[.,1],w20):/mean(z10[.,1],w10):+(1:-z10[.,1]):*(1-mean(z20[.,1],w20)):/(1-mean(z10[.,1],w10)))
	pred=J(0,1,0)
	i=1
	while(i<=nys){
		if (i>1 & ys[i]==ys[max(1\(i-1))]) pred=pred\pred[i-1]
		else{
			temp=logisticcdf(z10*coef20[.,i])
			pred=pred\mean(temp,w10c)
		}
		i=i+1
	}
	qcounter1=mm_quantile(ys,pred-(0\pred[1..(rows(pred)-1)]),((20..980)/1000)/max(pred))'
	//counterfactual distribution with characteristics and union as in 1979
	pred=J(0,1,0)
	i=1
	while(i<=nys){
		if (i>1 & ys[i]==ys[max(1\(i-1))]) pred=pred\pred[i-1]
		else{
			temp=logisticcdf(z10*coef20[.,i])
			pred=pred\mean(temp,w10)
		}
		i=i+1
	}
	qcounter2=mm_quantile(ys,pred-(0\pred[1..(rows(pred)-1)]),((20..980)/1000)/max(pred))'
	//counterfactual distribution with minimum wage and characteristics as in 1979
	pred=wdist1(y10,w10,ys[1..sum(ys:<=3)]')
	pred=pred:/mean(y10:<=3,w10):*mean(logisticcdf(z10*coef20[.,sum(ys:<=3)+1]),w10)
	i=sum(ys:<=3)+1
	while(i<=nys){
		if (i>(sum(ys:<=3)+1) & ys[i]==ys[i-1]) pred=pred\pred[i-1]
		else{
			temp=logisticcdf(z10*coef20[.,i])
			temp=temp
			pred=pred\mean(temp,w10)
		}
		i=i+1
	}
	qcounter3=mm_quantile(ys,pred-(0\pred[1..(rows(pred)-1)]),((20..980)/1000)/max(pred))'
	results=log(q1979),log(q1988),log(qcounter1),log(qcounter2),log(qcounter3)
	return(results)
}

**************************************
*Estimation: distribution regression
**************************************
*Men
*logistic link function
use "${data}data.dta", clear
mata 
res_logit=cal_dr("select10","select20","logit",ev=.)
fh=fopen("${results}men_logit","w")
fputmatrix(fh,res_logit)
fclose(fh)
end
*bootstrap
preserve
forvalues i=1/1{
	set seed `i'
	bsample 
	mata temp=cal_dr("select10","select20","logit",ev=.)
	mata fh=fopen("${results}boot","a")
	mata fputmatrix(fh,temp)
	mata fclose(fh)
	dis `i'
	restore, preserve
}
*inverted order
mata
results=inv_logit("select10","select20")
fh=fopen("${results}men_inv_logit","w")
fputmatrix(fh, results)
fclose(fh)
end
*bootstrap inverted order
preserve
forvalues i=1/1{
	set seed `i'
	bsample 
	mata: temp=inv_logit("select10","select20")
	mata: fh=fopen("${results}boot_inv","a")
	mata: fputmatrix(fh, temp)
	mata: fclose(fh)
	dis `i'
	restore, preserve
}
*Other link functions
res_prob=cal_dr("select10","select20","probit",ev=.)
res_lpm=cal_dr("select10","select20","lpm",ev=.)
res_cauchit=cal_dr("select10","select20","cauchit",ev=.)
res_loglog=cal_dr("select10","select20","loglog",ev=.)
mata matsave "${results}compare_dr.dta" res_logit res_prob res_lpm res_cauchit res_loglog
end
*Women
keep if female
mata
res_logit=cal_dr("select11","select21","logit",ev=.)
fh=fopen("${results}women_logit","w")
fputmatrix(fh,res_logit)
fclose(fh)
end
*bootstrap
preserve
forvalues i=1/1{
	set seed `i'
	bsample 
	mata temp=cal_dr("select11","select21","logit",ev=.)
	mata fh=fopen("${results}bootw","a")
	mata fputmatrix(fh,temp)
	mata: fclose(fh)
	dis `i'
	restore, preserve
}
*inverted order
mata
results=inv_logit("select11","select21")
fh=fopen("${results}women_inv_logit","w")
fputmatrix(fh, results)
fclose(fh)
end
use "${data}data.dta", clear
*bootstrap inverted order
preserve
forvalues i=1/1{
	set seed `i'
	bsample 
	mata: temp=inv_logit("select11","select21")
	mata fh=fopen("${results}bootw","a")
	mata fputmatrix(fh,temp)
	mata: fclose(fh)
	dis `i'
	restore, preserve
}
*Other link functions
res_prob=cal_dr("select11","select21","probit",ev=.)
res_lpm=cal_dr("select11","select21","lpm",ev=.)
res_cauchit=cal_dr("select11","select21","cauchit",ev=.)
res_loglog=cal_dr("select11","select21","loglog",ev=.)
mata matsave "${results}w_compare_dr.dta" res_logit res_prob res_lpm res_cauchit res_loglog
