*Change the folders
* The folder $data must contain the file "data.dta".
* The folder $results must contain the counterfactual distributions estimated by the files "estimation dr.do" and "estimation cqr.do".
* The graphs will be saved in the folder $graphs
global data "C:\Users\Blaise\Dropbox\COUNTERFACTUAL\Replication files\Data\"
global results "C:\Users\Blaise\Dropbox\COUNTERFACTUAL\Replication files\Results\"
global graphs "C:\Users\Blaise\Documents\A_travail\Quantile\process\DFL\Graphs\"

*Mata function calculating the uniform bands
cap mata mata drop ev_boot()
mata numeric matrix ev_boot(numeric matrix qte_cov_boot, numeric rowvector qte_cov_def, numeric matrix qte_cov_quant, numeric scalar max, numeric scalar min, numeric scalar level, numeric scalar tband)
{
	Vuqf=mean((qte_cov_boot:-mean(qte_cov_boot)):^2):*rows(qte_cov_boot):/(rows(qte_cov_boot)-1)
	seuqf=sqrt(Vuqf)
	if(tband==.){
		seuqf_nonzero=(seuqf:<=10^-15):*10^10:+seuqf
		Kuqf=abs(qte_cov_boot-qte_cov_def#J(rows(qte_cov_boot),1,1)):/(seuqf_nonzero#J(rows(qte_cov_boot),1,1))
		sel=(sum(rowmin(qte_cov_quant):<min)+1)..sum(rowmax(qte_cov_quant):<=max)
		tboot=rowmax(Kuqf[.,sel])
		tband=mm_quantile(tboot,1,level*0.01)
	}
	lb=qte_cov_def-seuqf*tband
	ub=qte_cov_def+seuqf*tband
	return((seuqf',lb',ub'))
}

cap mata mata drop wdist()
mata real wdist(y,w,ev) return(mean(y:<=(J(rows(y),1,1)*ev),w))

*Figure 1
use "${data}data.dta", clear
keep if female==0
*data
mata
y10=st_data(.,"wage","select10")
y20=st_data(.,"wage","select20")
y10=log(y10)
y20=log(y20)
w10=st_data(.,"eweight","select10")
w20=st_data(.,"eweight","select20")
ev=uniqrows(sort(y10\y20,1))'
//point estimates
fh=fopen("${results}men_logit","r")
men_logit=fgetmatrix(fh)
fclose(fh)
q79=men_logit[.,1]
q88=men_logit[.,2]
qc1=men_logit[.,3]
qc2=men_logit[.,4]
qc3=men_logit[.,5]
//bootstrap
fh=fopen("${results}boot","r")
a=fgetmatrix(fh)
q79b=q88b=qc1b=qc2b=qc3b=J(0,961,.)
while(rows(a)>1){
	q79b=q79b\a[.,1]'
	q88b=q88b\a[.,2]'
	qc1b=qc1b\a[.,3]'
	qc2b=qc2b\a[.,4]'
	qc3b=qc3b\a[.,5]'
	a=fgetmatrix(fh)
}
//smoothing of the quantile effects
quantile = (20..980)'/1000
q88s=q88
q79s=q79
qc1s=qc1
qc2s=qc2
qc3s=qc3
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88s[i]=mean(q88,wq)
	q79s[i]=mean(q79,wq)
	qc1s[i]=mean(qc1,wq)
	qc2s[i]=mean(qc2,wq)
	qc3s[i]=mean(qc3,wq)
}
q88bs=q79bs=qc1bs=qc2bs=qc3bs=q88b
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88bs[.,i]=mean(q88b',wq)'
	q79bs[.,i]=mean(q79b',wq)'
	qc1bs[.,i]=mean(qc1b',wq)'
	qc2bs[.,i]=mean(qc2b',wq)'
	qc3bs[.,i]=mean(qc3b',wq)'
}

//uniform confidence bands
tot=ev_boot(q88bs-q79bs,q88s'-q79s',(20..980)'/1000,0.98,0.02,95,a=.)
min=ev_boot(q88bs-qc1bs,q88s'-qc1s',(20..980)'/1000,0.98,0.02,95,a=.)
uni=ev_boot(qc1bs-qc2bs,qc1s'-qc2s',(20..980)'/1000,0.98,0.02,95,a=.)
char=ev_boot(qc2bs-qc3bs,qc2s'-qc3s',(20..980)'/1000,0.98,0.02,95,a=.)
coef=ev_boot(qc3bs-q79bs,qc3s'-q79s',(20..980)'/1000,0.98,0.02,95,a=.)

st_addvar("double", ("tots", "tots_lb", "tots_ub", "tots_se", "mins", "mins_lb", "mins_ub", "mins_se", "unis", "unis_lb", "unis_ub", "unis_se", "chars", "chars_lb", "chars_ub", "chars_se", "coefs", "coefs_lb", "coefs_ub", "coefs_se", "q88s", "q79s", "quantile"))
st_store((1..961)',"tots",q88s-q79s)
st_store((1..961)',"tots_lb",tot[.,2])
st_store((1..961)',"tots_ub",tot[.,3])
st_store((1..961)',"tots_se",tot[.,1])
st_store((1..961)',"mins",q88s-qc1s)
st_store((1..961)',"mins_lb",min[.,2])
st_store((1..961)',"mins_ub",min[.,3])
st_store((1..961)',"mins_se",min[.,1])
st_store((1..961)',"unis",qc1s-qc2s)
st_store((1..961)',"unis_lb",uni[.,2])
st_store((1..961)',"unis_ub",uni[.,3])
st_store((1..961)',"unis_se",uni[.,1])
st_store((1..961)',"chars",qc2s-qc3s)
st_store((1..961)',"chars_lb",char[.,2])
st_store((1..961)',"chars_ub",char[.,3])
st_store((1..961)',"chars_se",char[.,1])
st_store((1..961)',"coefs",qc3s-q79s)
st_store((1..961)',"coefs_lb",coef[.,2])
st_store((1..961)',"coefs_ub",coef[.,3])
st_store((1..961)',"coefs_se",coef[.,1])
st_store((1..961)',"q88s",q88s)
st_store((1..961)',"q79s",q79s)
st_store((1..961)',"quantile",quantile)
st_addvar("double", ("qc1s", "qc2s", "qc3s"))
st_store((1..961)',"qc1s",qc1s)
st_store((1..961)',"qc2s",qc2s)
st_store((1..961)',"qc3s",qc3s)
end

set scheme s1color
twoway (line q88s  quantile in 1/961) (line q79s  quantile in 1/961), ytitle(Quantiles) legend(order(1 "1988" 2 "1979") position(4) ring(0) rows(2)) xtitle("") title("Observed quantile functions") name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea tots_lb tots_ub quantile in 1/961, bcolor(ltblue)) (line tots quantile in 1/961, lcolor(edkblue)), legend(off) ytitle(QE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw ylabel(-0.3 -0.2 -0.1 0 0.1, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea mins_lb mins_ub quantile in 1/961, bcolor(ltblue)) (line mins quantile in 1/961, lcolor(edkblue)), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(men_min, replace) nodraw ylabel(-0.3 -0.2 -0.1 0 0.1, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea unis_lb unis_ub quantile in 1/961, bcolor(ltblue)) (line unis quantile in 1/961, lcolor(edkblue)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw  ylabel(-0.05 -0.025 0) ylabel(-0.3 -0.2 -0.1 0 0.1, grid gmin gmax) ysc(r(-0.3 0.15))
twoway (rarea chars_lb chars_ub quantile in 1/961, bcolor(ltblue)) (line chars quantile in 1/961, lcolor(edkblue)), legend(size(large) order(2 "QE") region(style(none))) ytitle(QE) xtitle(Quantile) title("Composition") name(men_char, replace) nodraw fysize(45) ylabel(-0.3 -0.2 -0.1 0 0.1, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea coefs_lb coefs_ub quantile in 1/961, bcolor(ltblue)) (line coefs quantile in 1/961, lcolor(edkblue)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Quantile) title("Wage structure") name(men_resid, replace) nodraw fysize(45) ylabel(-0.3 -0.2 -0.1 0 0.1, gmin gmax grid) ysc(r(-0.3 0.15))
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/Figure1.eps", replace
graph export "${graphs}/Figure1.emf", replace

set scheme s1mono
twoway (line q88s  quantile in 1/961) (line q79s  quantile in 1/961), ytitle(Quantiles) legend(order(1 "1988" 2 "1979") position(4) ring(0) rows(2)) xtitle("") title("Observed quantile functions") name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea tots_lb tots_ub quantile in 1/961, bcolor(gs8)) (line tots quantile in 1/961, lcolor(gs1)), legend(off) ytitle(QE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw ylabel(-0.3 -0.2 -0.1 0 0.1, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea mins_lb mins_ub quantile in 1/961, bcolor(gs8)) (line mins quantile in 1/961, lcolor(gs1)), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(men_min, replace) nodraw ylabel(-0.3 -0.2 -0.1 0 0.1, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea unis_lb unis_ub quantile in 1/961, bcolor(gs8)) (line unis quantile in 1/961, lcolor(gs1)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw  ylabel(-0.05 -0.025 0) ylabel(-0.3 -0.2 -0.1 0 0.1, grid gmin gmax) ysc(r(-0.3 0.15))
twoway (rarea chars_lb chars_ub quantile in 1/961, bcolor(gs8)) (line chars quantile in 1/961, lcolor(gs1)), legend(size(large) order(2 "QE") region(style(none))) ytitle(QE) xtitle(Quantile) title(Composition) name(men_char, replace) nodraw fysize(45) ylabel(-0.3 -0.2 -0.1 0 0.1, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea coefs_lb coefs_ub quantile in 1/961, bcolor(gs8)) (line coefs quantile in 1/961, lcolor(gs1)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Quantile) title(Wage structure) name(men_resid, replace) nodraw fysize(45) ylabel(-0.3 -0.2 -0.1 0 0.1, gmin gmax grid) ysc(r(-0.3 0.15))
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/Figure1_bw.eps", replace
graph export "${graphs}/Figure1_bw.emf", replace

*Figure 2
mata
d88=wdist(q88,1,ev)
d79=wdist(q79,1,ev)
dc1=wdist(qc1,1,ev)
dc2=wdist(qc2,1,ev)
dc3=wdist(qc3,1,ev)
d79b=d88b=dc1b=dc2b=dc3b=J(rows(q79b),cols(d88),.)
d88b=J(rows(q79b),cols(d88),.)
for(i=1;i<=rows(q79b);i++){
	d79b[i,.]=wdist(q79b[i,.]',1,ev)
	d88b[i,.]=wdist(q88b[i,.]',1,ev)
	dc1b[i,.]=wdist(qc1b[i,.]',1,ev)
	dc2b[i,.]=wdist(qc2b[i,.]',1,ev)
	dc3b[i,.]=wdist(qc3b[i,.]',1,ev)
}
d88s=d79s=dc1s=dc2s=dc3s=dc3
for(i=1;i<=6900;i++){
wq=mm_kern("gaussian",(ev:-ev[i]):/0.015)'
d88s[i]=mean(d88',wq)
d79s[i]=mean(d79',wq)
dc1s[i]=mean(dc1',wq)
dc2s[i]=mean(dc2',wq)
dc3s[i]=mean(dc3',wq)
}
d88bs=d79bs=dc1bs=dc2bs=dc3bs=d88b
for(i=1;i<=6900;i++){
	wq=mm_kern("gaussian",(ev:-ev[i]):/0.015)'
	d88bs[.,i]=mean(d88b',wq)'
	d79bs[.,i]=mean(d79b',wq)'
	dc1bs[.,i]=mean(dc1b',wq)'
	dc2bs[.,i]=mean(dc2b',wq)'
	dc3bs[.,i]=mean(dc3b',wq)'
}
tot_band=ev_boot(d88bs-d79bs,d88s-d79s,(d79s',d88s'),0.98,0.02,95,ttot=.)
min_band=ev_boot(d88bs-dc1bs,d88s-dc1s,(dc1s',d88s'),0.98,0.02,95,tmin=.)
uni_band=ev_boot(dc1bs-dc2bs,dc1s-dc2s,(dc2s',dc1s'),0.98,0.02,95,tuni=.)
char_band=ev_boot(dc2bs-dc3bs,dc2s-dc3s,(dc3s',dc2s'),0.98,0.02,95,tchar=.)
coef_band=ev_boot(dc3bs-d79bs,dc3s-d79s,(d79s',dc3s'),0.98,0.02,95,tcoef=.)
st_addvar("double", ("dtots", "dtots_lb", "dtots_ub","dmins","dmins_lb","dmins_ub","dunis","dunis_lb","dunis_ub","dchars","dchars_lb","dchars_ub","dcoefs","dcoefs_lb","dcoefs_ub","d79s","d88s","dc1s","dc2s","dc3s","ev"))
st_store((1..6900)',"dtots",d88s'-d79s')
st_store((1..6900)',"dtots_lb",tot_band[.,2])
st_store((1..6900)',"dtots_ub",tot_band[.,3])
st_store((1..6900)',"dmins",d88s'-dc1s')
st_store((1..6900)',"dmins_lb",min_band[.,2])
st_store((1..6900)',"dmins_ub",min_band[.,3])
st_store((1..6900)',"dunis",dc1s'-dc2s')
st_store((1..6900)',"dunis_lb",uni_band[.,2])
st_store((1..6900)',"dunis_ub",uni_band[.,3])
st_store((1..6900)',"dchars",dc2s'-dc3s')
st_store((1..6900)',"dchars_lb",char_band[.,2])
st_store((1..6900)',"dchars_ub",char_band[.,3])
st_store((1..6900)',"dcoefs",dc3s'-d79s')
st_store((1..6900)',"dcoefs_lb",coef_band[.,2])
st_store((1..6900)',"dcoefs_ub",coef_band[.,3])
st_store((1..6900)',"d79s",d79s')
st_store((1..6900)',"d88s",d88s')
st_store((1..6900)',"ev",ev')
st_store((1..6900)',"dc1s",dc1s')
st_store((1..6900)',"dc2s",dc2s')
st_store((1..6900)',"dc3s",dc3s')
end

set scheme s1mono
twoway (line d88s ev if ev>0.7 & ev<3) (line d79s ev if ev>0.7 & ev<3), ytitle(CDFs) legend(order(1 "1988" 2 "1979") position(4) ring(0) rows(2)) xtitle("") title(Observed distribution functions) name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea dtots_lb dtots_ub ev if ev>0.7 & ev<3, bcolor(gs5)) (line dtots ev if ev>0.7 & ev<3, lcolor(gs1)), legend(off) ytitle(DE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw ylabel(-0.05 0 0.05 0.1, gmax gmin grid)
twoway (rarea dmins_lb dmins_ub ev if ev>0.7 & ev<3, bcolor(gs5)) (line dmins ev if ev>0.7 & ev<3, lcolor(gs1)), legend(off) xtitle("") ytitle(DE) title(Minimum wage) name(men_min, replace) nodraw ylabel(-0.05 0 0.05 0.1, gmax gmin grid)
twoway (rarea dunis_lb dunis_ub ev if ev>0.7 & ev<3, bcolor(gs5)) (line dunis ev if ev>0.7 & ev<3, lcolor(gs1)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw ylabel(-0.05 0 0.05 0.1, gmax gmin grid)
twoway (rarea dchars_lb dchars_ub ev if ev>0.7 & ev<3, bcolor(gs5)) (line dchars ev if ev>0.7 & ev<3, lcolor(gs1)), legend(size(large) order(2 "DE") region(style(none))) ytitle(DE) xtitle(Log real wage) title(Composition) name(men_char, replace) nodraw fysize(45) ylabel(-0.05 0 0.05 0.1, gmax gmin grid)
twoway (rarea dcoefs_lb dcoefs_ub ev if ev>0.7 & ev<3, bcolor(gs5)) (line dcoefs ev if ev>0.7 & ev<3, lcolor(gs1)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Log real wage) title(Wage structure) name(men_resid, replace) nodraw fysize(45) ylabel(-0.05 0 0.05 0.1, gmax gmin grid)
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/Figure2_bw.eps", replace
graph export "${graphs}/Figure2_bw.emf", replace

set scheme s1color
twoway (line d88s ev if ev>0.7 & ev<3) (line d79s ev if ev>0.7 & ev<3), ytitle(CDFs) legend(order(1 "1988" 2 "1979") position(4) ring(0) rows(2)) xtitle("") title(Observed distribution functions) name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea dtots_lb dtots_ub ev if ev>0.7 & ev<3, bcolor(ltblue)) (line dtots ev if ev>0.7 & ev<3, lcolor(edkblue)), legend(off) ytitle(DE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw ylabel(-0.05 0 0.05 0.1, gmax gmin grid)
twoway (rarea dmins_lb dmins_ub ev if ev>0.7 & ev<3, bcolor(ltblue)) (line dmins ev if ev>0.7 & ev<3, lcolor(edkblue)), legend(off) xtitle("") ytitle(DE) title(Minimum wage) name(men_min, replace) nodraw ylabel(-0.05 0 0.05 0.1, gmax gmin grid)
twoway (rarea dunis_lb dunis_ub ev if ev>0.7 & ev<3, bcolor(ltblue)) (line dunis ev if ev>0.7 & ev<3, lcolor(edkblue)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw ylabel(-0.05 0 0.05 0.1, gmax gmin grid)
twoway (rarea dchars_lb dchars_ub ev if ev>0.7 & ev<3, bcolor(ltblue)) (line dchars ev if ev>0.7 & ev<3, lcolor(edkblue)), legend(size(large) order(2 "DE") region(style(none))) ytitle(DE) xtitle(Log real wage) title(Composition) name(men_char, replace) nodraw fysize(45) ylabel(-0.05 0 0.05 0.1, gmax gmin grid)
twoway (rarea dcoefs_lb dcoefs_ub ev if ev>0.7 & ev<3, bcolor(ltblue)) (line dcoefs ev if ev>0.7 & ev<3, lcolor(edkblue)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Log real wage) title(Wage structure) name(men_resid, replace) nodraw fysize(45) ylabel(-0.05 0 0.05 0.1, gmax gmin grid)
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/Figure2.eps", replace
graph export "${graphs}/Figure2.emf", replace

*Figure 3
mata
l88=runningsum(exp(q88))':/sum(exp(q88))
l79=runningsum(exp(q79))':/sum(exp(q79))
lc1=runningsum(exp(qc1))':/sum(exp(qc1))
lc2=runningsum(exp(qc2))':/sum(exp(qc2))
lc3=runningsum(exp(qc3))':/sum(exp(qc3))
l79b=l88b=lc1b=lc2b=lc3b=J(rows(q79b),cols(l88),.)
for(i=1;i<=rows(q79b);i++){
	l79b[i,.]=runningsum(exp(q79b[i,.])):/sum(exp(q79b[i,.]))
	l88b[i,.]=runningsum(exp(q88b[i,.])):/sum(exp(q88b[i,.]))
	lc1b[i,.]=runningsum(exp(qc1b[i,.])):/sum(exp(qc1b[i,.]))
	lc2b[i,.]=runningsum(exp(qc2b[i,.])):/sum(exp(qc2b[i,.]))
	lc3b[i,.]=runningsum(exp(qc3b[i,.])):/sum(exp(qc3b[i,.]))
}
st_addvar("double", ("l79","l88","lc1","lc2","lc3"))
st_store((1..961)',"l79",l79')
st_store((1..961)',"l88",l88')
st_store((1..961)',"lc1",lc1')
st_store((1..961)',"lc2",lc2')
st_store((1..961)',"lc3",lc3')
st_addvar("double", ("ltot", "ltot_lb", "ltot_ub", "ltot_se", "lmin", "lmin_lb", "lmin_ub", "lmin_se", "luni", "luni_lb", "luni_ub", "luni_se", "lchar", "lchar_lb", "lchar_ub", "lchar_se", "lcoef", "lcoef_lb", "lcoef_ub", "lcoef_se"))
tot=ev_boot(l88b-l79b, l88-l79, (20..980)'/1000, 0.97, 0.03, 95, a=.)
st_store((1..961)',"ltot",l88'-l79')
st_store((1..961)',"ltot_lb",tot[.,2])
st_store((1..961)',"ltot_ub",tot[.,3])
st_store((1..961)',"ltot_se",tot[.,1])
tot=ev_boot(l88b-lc1b,l88-lc1,(20..980)'/1000, 0.97, 0.03, 95,a=.)
st_store((1..961)',"lmin",l88'-lc1')
st_store((1..961)',"lmin_lb",tot[.,2])
st_store((1..961)',"lmin_ub",tot[.,3])
st_store((1..961)',"lmin_se",tot[.,1])
tot=ev_boot(lc1b-lc2b,lc1-lc2,(20..980)'/1000, 0.97, 0.03, 95,a=.)
st_store((1..961)',"luni",lc1'-lc2')
st_store((1..961)',"luni_lb",tot[.,2])
st_store((1..961)',"luni_ub",tot[.,3])
st_store((1..961)',"luni_se",tot[.,1])
tot=ev_boot(lc2b-lc3b,lc2-lc3,(20..980)'/1000, 0.97, 0.03, 95,a=.)
st_store((1..961)',"lchar",lc2'-lc3')
st_store((1..961)',"lchar_lb",tot[.,2])
st_store((1..961)',"lchar_ub",tot[.,3])
st_store((1..961)',"lchar_se",tot[.,1])
tot=ev_boot(lc3b-l79b,lc3-l79,(20..980)'/1000, 0.97, 0.03, 95,a=.)
st_store((1..961)',"lcoef",lc3'-l79')
st_store((1..961)',"lcoef_lb",tot[.,2])
st_store((1..961)',"lcoef_ub",tot[.,3])
st_store((1..961)',"lcoef_se",tot[.,1])
end

set scheme s1mono
twoway (line l88 quantile in 1/961) (line l79 quantile in 1/961), ytitle(Observed Lorenz curves) legend(order(1 "1988" 2 "1979") rows(2) position(4) ring(0)) xtitle("") title(Lorenz curves) name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea ltot_lb ltot_ub quantile if quantile>0.02 & quantile<0.98, bcolor(gs5)) (line ltot quantile if quantile>0.02 & quantile<0.98, lcolor(gs1)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) ytitle(LE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid)
twoway (rarea lmin_lb lmin_ub quantile if quantile>0.02 & quantile<0.98, bcolor(gs5)) (line lmin quantile if quantile>0.02 & quantile<0.98, lcolor(gs1)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) xtitle("") ytitle(LE) title(Minimum wage) name(men_min, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid)
twoway (rarea luni_lb luni_ub quantile if quantile>0.02 & quantile<0.98, bcolor(gs5)) (line luni quantile if quantile>0.02 & quantile<0.98, lcolor(gs1)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid)
twoway (rarea lchar_lb lchar_ub quantile if quantile>0.02 & quantile<0.98, bcolor(gs5)) (line lchar quantile if quantile>0.02 & quantile<0.98, lcolor(gs1)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(size(large) order(2 "LE") region(style(none))) ytitle(LE) xtitle(Quantile) title(Composition) name(men_char, replace) nodraw fysize(45) ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid)
twoway (rarea lcoef_lb lcoef_ub quantile if quantile>0.02 & quantile<0.98, bcolor(gs5)) (line lcoef quantile if quantile>0.02 & quantile<0.98, lcolor(gs1)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Quantile) title(Wage structure) name(men_resid, replace) nodraw fysize(45) ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid)
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/Figure3_bw.eps", replace
graph export "${graphs}/Figure3_bw.emf", replace

set scheme s1color
twoway (line l88 quantile in 1/961) (line l79 quantile in 1/961), ytitle(Observed Lorenz curves) legend(order(1 "1988" 2 "1979") rows(2) position(4) ring(0)) xtitle("") title(Lorenz curves) name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea ltot_lb ltot_ub quantile if quantile>0.02 & quantile<0.98, bcolor(ltblue)) (line ltot quantile if quantile>0.02 & quantile<0.98, lcolor(edkblue)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) ytitle(LE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid)
twoway (rarea lmin_lb lmin_ub quantile if quantile>0.02 & quantile<0.98, bcolor(ltblue)) (line lmin quantile if quantile>0.02 & quantile<0.98, lcolor(edkblue)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) xtitle("") ytitle(LE) title(Minimum wage) name(men_min, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid)
twoway (rarea luni_lb luni_ub quantile if quantile>0.02 & quantile<0.98, bcolor(ltblue)) (line luni quantile if quantile>0.02 & quantile<0.98, lcolor(edkblue)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid)
twoway (rarea lchar_lb lchar_ub quantile if quantile>0.02 & quantile<0.98, bcolor(ltblue)) (line lchar quantile if quantile>0.02 & quantile<0.98, lcolor(edkblue)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(size(large) order(2 "LE") region(style(none))) ytitle(LE) xtitle(Quantile) title(Composition) name(men_char, replace) nodraw fysize(45) ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid)
twoway (rarea lcoef_lb lcoef_ub quantile if quantile>0.02 & quantile<0.98, bcolor(ltblue)) (line lcoef quantile if quantile>0.02 & quantile<0.98, lcolor(edkblue)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Quantile) title(Wage structure) name(men_resid, replace) nodraw fysize(45) ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid)
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/Figure3.eps", replace
graph export "${graphs}/Figure3.emf", replace

*Mata function producing the tables
cap mata mata drop table()
mata void table(real colvector q88, real colvector q79, real colvector qc1, real colvector qc2, real colvector qc3, real matrix q88b, real matrix q79b, real matrix qc1b, real matrix qc2b, real matrix qc3b, string scalar name)
{
	table1=J(28,5,.)
	table1[1,1]=variance(q88)^0.5-variance(q79)^0.5
	table1[1,2]=variance(q88)^0.5-variance(qc1)^0.5
	table1[1,3]=variance(qc1)^0.5-variance(qc2)^0.5
	table1[1,4]=variance(qc2)^0.5-variance(qc3)^0.5
	table1[1,5]=variance(qc3)^0.5-variance(q79)^0.5
	temp1=temp2=temp3=temp4=temp5=J(0,1,.)
	for(i=1;i<=rows(q79b);i++){
		temp1=temp1\variance(q88b[i,.]')^0.5-variance(q79b[i,.]')^0.5
		temp2=temp2\variance(q88b[i,.]')^0.5-variance(qc1b[i,.]')^0.5
		temp3=temp3\variance(qc1b[i,.]')^0.5-variance(qc2b[i,.]')^0.5
		temp4=temp4\variance(qc2b[i,.]')^0.5-variance(qc3b[i,.]')^0.5
		temp5=temp5\variance(qc3b[i,.]')^0.5-variance(q79b[i,.]')^0.5
	}
	table1[2,1]=variance(temp1)^0.5
	table1[2,2]=variance(temp2)^0.5
	table1[2,3]=variance(temp3)^0.5
	table1[2,4]=variance(temp4)^0.5
	table1[2,5]=variance(temp5)^0.5
	table1[3,2]=table1[1,2]/table1[1,1]
	table1[3,3]=table1[1,3]/table1[1,1]
	table1[3,4]=table1[1,4]/table1[1,1]
	table1[3,5]=table1[1,5]/table1[1,1]
	table1[4,2]=variance(temp2:/temp1)^0.5
	table1[4,3]=variance(temp3:/temp1)^0.5
	table1[4,4]=variance(temp4:/temp1)^0.5
	table1[4,5]=variance(temp5:/temp1)^0.5
	table1[5,1]=q88[881]-q88[81]-(q79[881]-q79[81])
	table1[5,2]=q88[881]-q88[81]-(qc1[881]-qc1[81])
	table1[5,3]=qc1[881]-qc1[81]-(qc2[881]-qc2[81])
	table1[5,4]=qc2[881]-qc2[81]-(qc3[881]-qc3[81])
	table1[5,5]=qc3[881]-qc3[81]-(q79[881]-q79[81])
	temp1=temp2=temp3=temp4=temp5=J(0,1,.)
	for(i=1;i<=rows(q79b);i++){
		temp1=temp1\q88b[i,881]-q88b[i,81]-(q79b[i,881]-q79b[i,81])
		temp2=temp2\q88b[i,881]-q88b[i,81]-(qc1b[i,881]-qc1b[i,81])
		temp3=temp3\qc1b[i,881]-qc1b[i,81]-(qc2b[i,881]-qc2b[i,81])
		temp4=temp4\qc2b[i,881]-qc2b[i,81]-(qc3b[i,881]-qc3b[i,81])
		temp5=temp5\qc3b[i,881]-qc3b[i,81]-(q79b[i,881]-q79b[i,81])
	}
	table1[6,1]=variance(temp1)^0.5
	table1[6,2]=variance(temp2)^0.5
	table1[6,3]=variance(temp3)^0.5
	table1[6,4]=variance(temp4)^0.5
	table1[6,5]=variance(temp5)^0.5
	table1[7,2]=table1[5,2]/table1[5,1]
	table1[7,3]=table1[5,3]/table1[5,1]
	table1[7,4]=table1[5,4]/table1[5,1]
	table1[7,5]=table1[5,5]/table1[5,1]
	table1[8,2]=variance(temp2:/temp1)^0.5
	table1[8,3]=variance(temp3:/temp1)^0.5
	table1[8,4]=variance(temp4:/temp1)^0.5
	table1[8,5]=variance(temp5:/temp1)^0.5
	table1[9,1]=q88[481]-q88[81]-(q79[481]-q79[81])
	table1[9,2]=q88[481]-q88[81]-(qc1[481]-qc1[81])
	table1[9,3]=qc1[481]-qc1[81]-(qc2[481]-qc2[81])
	table1[9,4]=qc2[481]-qc2[81]-(qc3[481]-qc3[81])
	table1[9,5]=qc3[481]-qc3[81]-(q79[481]-q79[81])
	temp1=temp2=temp3=temp4=temp5=J(0,1,.)
	for(i=1;i<=rows(q79b);i++){
		temp1=temp1\q88b[i,481]-q88b[i,81]-(q79b[i,481]-q79b[i,81])
		temp2=temp2\q88b[i,481]-q88b[i,81]-(qc1b[i,481]-qc1b[i,81])
		temp3=temp3\qc1b[i,481]-qc1b[i,81]-(qc2b[i,481]-qc2b[i,81])
		temp4=temp4\qc2b[i,481]-qc2b[i,81]-(qc3b[i,481]-qc3b[i,81])
		temp5=temp5\qc3b[i,481]-qc3b[i,81]-(q79b[i,481]-q79b[i,81])
	}	
	table1[10,1]=variance(temp1)^0.5
	table1[10,2]=variance(temp2)^0.5
	table1[10,3]=variance(temp3)^0.5
	table1[10,4]=variance(temp4)^0.5
	table1[10,5]=variance(temp5)^0.5
	table1[11,2]=table1[9,2]/table1[9,1]
	table1[11,3]=table1[9,3]/table1[9,1]
	table1[11,4]=table1[9,4]/table1[9,1]
	table1[11,5]=table1[9,5]/table1[9,1]
	table1[12,2]=variance(temp2:/temp1)^0.5
	table1[12,3]=variance(temp3:/temp1)^0.5
	table1[12,4]=variance(temp4:/temp1)^0.5
	table1[12,5]=variance(temp5:/temp1)^0.5
	table1[13,1]=q88[881]-q88[481]-(q79[881]-q79[481])
	table1[13,2]=q88[881]-q88[481]-(qc1[881]-qc1[481])
	table1[13,3]=qc1[881]-qc1[481]-(qc2[881]-qc2[481])
	table1[13,4]=qc2[881]-qc2[481]-(qc3[881]-qc3[481])
	table1[13,5]=qc3[881]-qc3[481]-(q79[881]-q79[481])
	temp1=temp2=temp3=temp4=temp5=J(0,1,.)
	for(i=1;i<=rows(q79b);i++){
		temp1=temp1\q88b[i,881]-q88b[i,481]-(q79b[i,881]-q79b[i,481])
		temp2=temp2\q88b[i,881]-q88b[i,481]-(qc1b[i,881]-qc1b[i,481])
		temp3=temp3\qc1b[i,881]-qc1b[i,481]-(qc2b[i,881]-qc2b[i,481])
		temp4=temp4\qc2b[i,881]-qc2b[i,481]-(qc3b[i,881]-qc3b[i,481])
		temp5=temp5\qc3b[i,881]-qc3b[i,481]-(q79b[i,881]-q79b[i,481])
	}	
	table1[14,1]=variance(temp1)^0.5
	table1[14,2]=variance(temp2)^0.5
	table1[14,3]=variance(temp3)^0.5
	table1[14,4]=variance(temp4)^0.5
	table1[14,5]=variance(temp5)^0.5
	table1[15,2]=table1[13,2]/table1[13,1]
	table1[15,3]=table1[13,3]/table1[13,1]
	table1[15,4]=table1[13,4]/table1[13,1]
	table1[15,5]=table1[13,5]/table1[13,1]
	table1[16,2]=variance(temp2:/temp1)^0.5
	table1[16,3]=variance(temp3:/temp1)^0.5
	table1[16,4]=variance(temp4:/temp1)^0.5
	table1[16,5]=variance(temp5:/temp1)^0.5
	table1[17,1]=q88[731]-q88[231]-(q79[731]-q79[231])
	table1[17,2]=q88[731]-q88[231]-(qc1[731]-qc1[231])
	table1[17,3]=qc1[731]-qc1[231]-(qc2[731]-qc2[231])
	table1[17,4]=qc2[731]-qc2[231]-(qc3[731]-qc3[231])
	table1[17,5]=qc3[731]-qc3[231]-(q79[731]-q79[231])
	temp1=temp2=temp3=temp4=temp5=J(0,1,.)
	for(i=1;i<=rows(q79b);i++){
		temp1=temp1\q88b[i,731]-q88b[i,231]-(q79b[i,731]-q79b[i,231])
		temp2=temp2\q88b[i,731]-q88b[i,231]-(qc1b[i,731]-qc1b[i,231])
		temp3=temp3\qc1b[i,731]-qc1b[i,231]-(qc2b[i,731]-qc2b[i,231])
		temp4=temp4\qc2b[i,731]-qc2b[i,231]-(qc3b[i,731]-qc3b[i,231])
		temp5=temp5\qc3b[i,731]-qc3b[i,231]-(q79b[i,731]-q79b[i,231])
	}
	table1[18,1]=variance(temp1)^0.5
	table1[18,2]=variance(temp2)^0.5
	table1[18,3]=variance(temp3)^0.5
	table1[18,4]=variance(temp4)^0.5
	table1[18,5]=variance(temp5)^0.5
	table1[19,2]=table1[17,2]/table1[17,1]
	table1[19,3]=table1[17,3]/table1[17,1]
	table1[19,4]=table1[17,4]/table1[17,1]
	table1[19,5]=table1[17,5]/table1[17,1]
	table1[20,2]=variance(temp2:/temp1)^0.5
	table1[20,3]=variance(temp3:/temp1)^0.5
	table1[20,4]=variance(temp4:/temp1)^0.5
	table1[20,5]=variance(temp5:/temp1)^0.5
	table1[21,1]=q88[931]-q88[31]-(q79[931]-q79[31])
	table1[21,2]=q88[931]-q88[31]-(qc1[931]-qc1[31])
	table1[21,3]=qc1[931]-qc1[31]-(qc2[931]-qc2[31])
	table1[21,4]=qc2[931]-qc2[31]-(qc3[931]-qc3[31])
	table1[21,5]=qc3[931]-qc3[31]-(q79[931]-q79[31])
	temp1=temp2=temp3=temp4=temp5=J(0,1,.)
	for(i=1;i<=rows(q79b);i++){
		temp1=temp1\q88b[i,931]-q88b[i,31]-(q79b[i,931]-q79b[i,31])
		temp2=temp2\q88b[i,931]-q88b[i,31]-(qc1b[i,931]-qc1b[i,31])
		temp3=temp3\qc1b[i,931]-qc1b[i,31]-(qc2b[i,931]-qc2b[i,31])
		temp4=temp4\qc2b[i,931]-qc2b[i,31]-(qc3b[i,931]-qc3b[i,31])
		temp5=temp5\qc3b[i,931]-qc3b[i,31]-(q79b[i,931]-q79b[i,31])
	}	
	table1[22,1]=variance(temp1)^0.5
	table1[22,2]=variance(temp2)^0.5
	table1[22,3]=variance(temp3)^0.5
	table1[22,4]=variance(temp4)^0.5
	table1[22,5]=variance(temp5)^0.5
	table1[23,2]=table1[21,2]/table1[21,1]
	table1[23,3]=table1[21,3]/table1[21,1]
	table1[23,4]=table1[21,4]/table1[21,1]
	table1[23,5]=table1[21,5]/table1[21,1]
	table1[24,2]=variance(temp2:/temp1)^0.5
	table1[24,3]=variance(temp3:/temp1)^0.5
	table1[24,4]=variance(temp4:/temp1)^0.5
	table1[24,5]=variance(temp5:/temp1)^0.5
	table1[25,1]=mm_gini(q88)^0.5-mm_gini(q79)^0.5
	table1[25,2]=mm_gini(q88)^0.5-mm_gini(qc1)^0.5
	table1[25,3]=mm_gini(qc1)^0.5-mm_gini(qc2)^0.5
	table1[25,4]=mm_gini(qc2)^0.5-mm_gini(qc3)^0.5
	table1[25,5]=mm_gini(qc3)^0.5-mm_gini(q79)^0.5
	temp1=temp2=temp3=temp4=temp5=J(0,1,.)
	for(i=1;i<=rows(q79b);i++){
		temp1=temp1\mm_gini(q88b[i,.]')^0.5-mm_gini(q79b[i,.]')^0.5
		temp2=temp2\mm_gini(q88b[i,.]')^0.5-mm_gini(qc1b[i,.]')^0.5
		temp3=temp3\mm_gini(qc1b[i,.]')^0.5-mm_gini(qc2b[i,.]')^0.5
		temp4=temp4\mm_gini(qc2b[i,.]')^0.5-mm_gini(qc3b[i,.]')^0.5
		temp5=temp5\mm_gini(qc3b[i,.]')^0.5-mm_gini(q79b[i,.]')^0.5
	}
	table1[26,1]=variance(temp1)^0.5
	table1[26,2]=variance(temp2)^0.5
	table1[26,3]=variance(temp3)^0.5
	table1[26,4]=variance(temp4)^0.5
	table1[26,5]=variance(temp5)^0.5
	table1[27,2]=table1[25,2]/table1[25,1]
	table1[27,3]=table1[25,3]/table1[25,1]
	table1[27,4]=table1[25,4]/table1[25,1]
	table1[27,5]=table1[25,5]/table1[25,1]
	table1[28,2]=variance(temp2:/temp1)^0.5
	table1[28,3]=variance(temp3:/temp1)^0.5
	table1[28,4]=variance(temp4:/temp1)^0.5
	table1[28,5]=variance(temp5:/temp1)^0.5
	st_matrix(name,round(table1:*1000):/10)
}
*Table 1
mata table(q88,q79,qc1,qc2,qc3,q88b,q79b,qc1b,qc2b,qc3b,"table1")
mat list table1

*Figure C1
mata
mata matuse "${results}compare_dr.dta"
st_addvar("double", ("mw_l", "mw_p", "mw_lin", "mw_c", "mw_loglog", "union_l", "union_p", "union_lin", "union_c", "union_loglog", "char_l", "char_p", "char_lin", "char_c", "char_loglog", "coef_l", "coef_p", "coef_lin", "coef_c", "coef_loglog"))
//smoothing
res_logits=res_logit
res_probs=res_prob
res_lpms=res_lpm
res_cauchits=res_cauchit
res_loglogs=res_loglog
for(i=1;i<=961;i++){
	for(c=1;c<=5;c++){
		wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
		res_logits[i,c]=mean(res_logit[,c],wq)
		res_probs[i,c]=mean(res_prob[,c],wq)
		res_lpms[i,c]=mean(res_lpm[,c],wq)
		res_cauchits[i,c]=mean(res_cauchit[,c],wq)
		res_loglogs[i,c]=mean(res_loglog[,c],wq)
	}
}
st_store((1..961)',"mw_l",res_logits[,2]:-res_logits[,3])
st_store((1..961)',"mw_p",res_probs[,2]:-res_probs[,3])
st_store((1..961)',"mw_lin",res_lpms[,2]:-res_lpms[,3])
st_store((1..961)',"mw_c",res_cauchits[,2]:-res_cauchits[,3])
st_store((1..961)',"mw_loglog",res_loglogs[,2]:-res_loglogs[,3])
st_store((1..961)',"union_l",res_logits[,3]:-res_logits[,4])
st_store((1..961)',"union_p",res_probs[,3]:-res_probs[,4])
st_store((1..961)',"union_lin",res_lpms[,3]:-res_lpms[,4])
st_store((1..961)',"union_c",res_cauchits[,3]:-res_cauchits[,4])
st_store((1..961)',"union_loglog",res_loglogs[,3]:-res_loglogs[,4])
st_store((1..961)',"char_l",res_logits[,4]:-res_logits[,5])
st_store((1..961)',"char_p",res_probs[,4]:-res_probs[,5])
st_store((1..961)',"char_lin",res_lpms[,4]:-res_lpms[,5])
st_store((1..961)',"char_c",res_cauchits[,4]:-res_cauchits[,5])
st_store((1..961)',"char_loglog",res_loglogs[,4]:-res_loglogs[,5])
st_store((1..961)',"coef_l",res_logits[,5]:-res_logits[,1])
st_store((1..961)',"coef_p",res_probs[,5]:-res_probs[,1])
st_store((1..961)',"coef_lin",res_lpms[,5]:-res_lpms[,1])
st_store((1..961)',"coef_c",res_cauchits[,5]:-res_cauchits[,1])
st_store((1..961)',"coef_loglog",res_loglogs[,5]:-res_loglogs[,1])
end

set scheme s1color
twoway (line mw_l quantile, lp(shortdash)) (line mw_p quantile, lp(shortdash)) (line mw_lin quantile) (line mw_c quantile) (line mw_loglog quantile), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(comp_min, replace) nodraw ylabel(, grid)
twoway (line union_l quantile, lp(shortdash)) (line union_p quantile, lp(shortdash)) (line union_lin quantile) (line union_c quantile) (line union_loglog quantile), legend(off) xtitle("") ytitle("") title(De-unionization) name(comp_uni, replace) nodraw ylabel(, grid)
twoway (line char_l quantile, lp(shortdash)) (line char_p quantile, lp(shortdash)) (line char_lin quantile) (line char_c quantile) (line char_loglog quantile), legend(symxsize(3) order(1 "Logit" 3 "Linear probability model" 5 "Complementary log-log") rows(3) region(style(none))) ytitle(QE) xtitle(Quantile) title(Composition) name(comp_char, replace) nodraw fysize(56) ylabel(, grid)
twoway (line coef_l quantile, lp(shortdash)) (line coef_p quantile, lp(shortdash)) (line coef_lin quantile) (line coef_c quantile) (line coef_loglog quantile), legend(symxsize(5) order(2 "Probit" 4 "Cauchit" - " ") region(style(none)) rows(3)) xtitle(Quantile) title(Wage structure) name(comp_resid, replace) nodraw fysize(56) ylabel(, grid)
graph combine comp_min comp_uni comp_char comp_resid, ycommon rows(2) imargin(tiny) xsize(8) ysize(8)
graph export "${graphs}FigureC1.eps", replace
graph export "${graphs}FigureC1.emf", replace

set scheme s1mono
twoway (line mw_l quantile, lc(black)) (line mw_p quantile, lp(shortdash) lc(black)) (line mw_lin quantile, lc(gs8) lp(solid)) (line mw_c quantile, lp(shortdash) lc(gs8)) (line mw_loglog quantile, lc(black) lp(". .")), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(comp_min, replace) nodraw ylabel(, grid)
twoway (line union_l quantile, lc(black)) (line union_p quantile, lp(shortdash) lc(black)) (line union_lin quantile, lc(gs8) lp(solid)) (line union_c quantile, lp(shortdash) lc(gs8)) (line union_loglog quantile, lc(black) lp(". .")), legend(off) xtitle("") ytitle("") title(De-unionization) name(comp_uni, replace) nodraw ylabel(, grid)
twoway (line char_l quantile, lc(black)) (line char_p quantile, lp(shortdash) lc(black)) (line char_lin quantile, lc(gs8) lp(solid)) (line char_c quantile, lp(shortdash) lc(gs8)) (line char_loglog quantile, lc(black) lp(". .")), legend(symxsize(3) order(1 "Logit" 3 "Linear probability model" 5 "Complementary log-log") rows(3) region(style(none))) ytitle(QE) xtitle(Quantile) title(Composition) name(comp_char, replace) nodraw fysize(56) ylabel(, grid)
twoway (line coef_l quantile, lc(black)) (line coef_p quantile, lp(shortdash) lc(black)) (line coef_lin quantile, lc(gs8) lp(solid)) (line coef_c quantile, lp(shortdash) lc(gs8)) (line coef_loglog quantile, lc(black) lp(". .")), legend(symxsize(5) order(2 "Probit" 4 "Cauchit" - " ") region(style(none)) rows(3)) xtitle(Quantile) title(Wage structure) name(comp_resid, replace) nodraw fysize(56) ylabel(, grid)
graph combine comp_min comp_uni comp_char comp_resid, ycommon rows(2) imargin(tiny) xsize(8) ysize(8)
graph export "${graphs}FigureC1_bw.eps", replace
graph export "${graphs}FigureC1_bw.emf", replace

*Table C2
mata
//Censored distribution regression
//censoring the estimates
q79=rowmax((q79,J(961,1,1.098612309)))
q88=rowmax((q88,J(961,1,.7923135757)))
qc1=rowmax((qc1,J(961,1,1.098612309)))
qc2=rowmax((qc2,J(961,1,1.098612309)))
qc3=rowmax((qc3,J(961,1,1.098612309)))
for(j=1;j<=rows(q88b);j++){
	q79b[j,.]=rowmax((q79b[j,.]',J(961,1,1.098612309)))'
	q88b[j,.]=rowmax((q88b[j,.]',J(961,1,.7923135757)))'
	qc1b[j,.]=rowmax((qc1b[j,.]',J(961,1,1.098612309)))'
	qc2b[j,.]=rowmax((qc2b[j,.]',J(961,1,1.098612309)))'
	qc3b[j,.]=rowmax((qc3b[j,.]',J(961,1,1.098612309)))'
}
//smoothing 
q88s=q79s=qc1s=qc2s=qc3s=qc3
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88s[i]=mean(q88,wq)
	q79s[i]=mean(q79,wq)
	qc1s[i]=mean(qc1,wq)
	qc2s[i]=mean(qc2,wq)
	qc3s[i]=mean(qc3,wq)
}
q88bs=q79bs=qc1bs=qc2bs=qc3bs=q88b
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88bs[.,i]=mean(q88b',wq)'
	q79bs[.,i]=mean(q79b',wq)'
	qc1bs[.,i]=mean(qc1b',wq)'
	qc2bs[.,i]=mean(qc2b',wq)'
	qc3bs[.,i]=mean(qc3b',wq)'
}
//First part of table C2
table(q88,q79,qc1,qc2,qc3,q88b,q79b,qc1b,qc2b,qc3b,"table2a")
end
mat list table2a
//generating the variables for Figure C2
mata
st_addvar("double", ("mincs", "unics", "charcs", "coefcs"))
st_store((1..961)',"mincs",q88s-qc1s)
st_store((1..961)',"unics",qc1s-qc2s)
st_store((1..961)',"charcs",qc2s-qc3s)
st_store((1..961)',"coefcs",qc3s-q79s)
end

//Censored quantile regression
mata
fh=fopen("${results}men_cqr","r")
men_qr=fgetmatrix(fh)
fclose(fh)
q79=men_qr[.,3]
q88=men_qr[.,4]
qc1=men_qr[.,5]
qc2=men_qr[.,6]
qc3=men_qr[.,7]
fh=fopen("${results}boot_men_cqr","r")
a=fgetmatrix(fh)
q79b=q88b=qc1b=qc2b=qc3b=J(0,961,.)
while(rows(a)>1){
	q79b=q79b\a[.,3]'
	q88b=q88b\a[.,4]'
	qc1b=qc1b\a[.,5]'
	qc2b=qc2b\a[.,6]'
	qc3b=qc3b\a[.,7]'
	a=fgetmatrix(fh)
}
fclose(fh)
//Second part of table C2
table(q88,q79,qc1,qc2,qc3,q88b,q79b,qc1b,qc2b,qc3b,"tableC2b")
end
mat list tableC2b
//generating the variables for Figure C2
mata
st_addvar("double", ("totcqr", "mincqr", "unicqr", "charcqr", "coefcqr"))
st_store((1..961)',"totcqr",q88-q79)
st_store((1..961)',"mincqr",q88-qc1)
st_store((1..961)',"unicqr",qc1-qc2)
st_store((1..961)',"charcqr",qc2-qc3)
st_store((1..961)',"coefcqr",qc3-q79)
end

*Figure C2
set scheme s1mono
twoway (line mins quantile, lc(black)) (line mincs quantile, lp(shortdash) lc(black)) (line mincqr quantile, lc(gs8) lp(solid)), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(comp_min, replace) nodraw ylabel(, grid)
twoway (line unis quantile, lc(black)) (line unics quantile, lp(shortdash) lc(black)) (line unicqr quantile, lc(gs8) lp(solid)), legend(off) xtitle("") ytitle("") title(De-unionization) name(comp_uni, replace) nodraw ylabel(, grid)
twoway (line chars quantile, lc(black)) (line charcs quantile, lp(shortdash) lc(black)) (line charcqr quantile, lc(gs8) lp(solid)), legend(symxsize(3) order(1 "Distribution regression" 3 "Censored quantile regression") rows(2) region(style(none))) ytitle(QE) xtitle(Quantile) title(Composition) name(comp_char, replace) nodraw fysize(52) ylabel(, grid)
twoway (line coefs quantile, lc(black)) (line coefcs quantile, lp(shortdash) lc(black)) (line coefcqr quantile, lc(gs8) lp(solid)) , legend(symxsize(5) order(2 "Censored distribution regression" 4 "") region(style(none)) rows(2) rowgap(4)) xtitle(Quantile) title(Wage structure) name(comp_resid, replace) nodraw fysize(52) ylabel(, grid)
graph combine comp_min comp_uni comp_char comp_resid, ycommon rows(2) imargin(tiny) xsize(8) ysize(8)
graph export "${graphs}FigureC2_bw.eps", replace
graph export "${graphs}FigureC2_bw.emf", replace

set scheme s1color
twoway (line mins quantile, lp(shortdash)) (line mincs quantile) (line mincqr quantile), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(comp_min, replace) nodraw ylabel(, grid)
twoway (line unis quantile, lp(shortdash)) (line unics quantile) (line unicqr quantile), legend(off) xtitle("") ytitle("") title(De-unionization) name(comp_uni, replace) nodraw ylabel(, grid)
twoway (line chars quantile, lp(shortdash)) (line charcs quantile) (line charcqr quantile), legend(symxsize(3) order(1 "Distribution regression" 3 "Censored quantile regression") rows(2) region(style(none))) ytitle(QE) xtitle(Quantile) title(Composition) name(comp_char, replace) nodraw fysize(52) ylabel(, grid)
twoway (line coefs quantile, lp(shortdash)) (line coefcs quantile) (line coefcqr quantile) , legend(symxsize(5) order(2 "Censored distribution regression" 4 "") region(style(none)) rows(2) rowgap(4)) xtitle(Quantile) title(Wage structure) name(comp_resid, replace) nodraw fysize(52) ylabel(, grid)
graph combine comp_min comp_uni comp_char comp_resid, ycommon rows(2) imargin(tiny) xsize(8) ysize(8)
graph export "${graphs}FigureC2.eps", replace
graph export "${graphs}FigureC2.emf", replace

*Table C3 - men
mata
//point estimates
fh=fopen("${results}men_inv_logit","r")
men_logit=fgetmatrix(fh)
fclose(fh)
q79=men_logit[.,1]
q88=men_logit[.,2]
qc1=men_logit[.,3]
qc2=men_logit[.,4]
qc3=men_logit[.,5]
//bootstrap
fh=fopen("${results}boot_inv","r")
a=fgetmatrix(fh)
q79b=q88b=qc1b=qc2b=qc3b=J(0,961,.)
while(rows(a)>1){
	q79b=q79b\a[.,1]'
	q88b=q88b\a[.,2]'
	qc1b=qc1b\a[.,3]'
	qc2b=qc2b\a[.,4]'
	qc3b=qc3b\a[.,5]'
	a=fgetmatrix(fh)
}
fclose(fh)
//smoothing of the quantile effects
quantile = (20..980)'/1000
q88s=q79s=qc1s=qc2s=qc3s=qc3
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88s[i]=mean(q88,wq)
	q79s[i]=mean(q79,wq)
	qc1s[i]=mean(qc1,wq)
	qc2s[i]=mean(qc2,wq)
	qc3s[i]=mean(qc3,wq)
}
q88bs=q79bs=qc1bs=qc2bs=qc3bs=q88b
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88bs[.,i]=mean(q88b',wq)'
	q79bs[.,i]=mean(q79b',wq)'
	qc1bs[.,i]=mean(qc1b',wq)'
	qc2bs[.,i]=mean(qc2b',wq)'
	qc3bs[.,i]=mean(qc3b',wq)'
}
table(q88,q79,qc1,qc2,qc3,q88b,q79b,qc1b,qc2b,qc3b,"tableC3a")
end
mat list tableC3a

*Figure C3
use "${data}data.dta", clear
keep if female==1
*data
mata
y10=st_data(.,"wage","select11")
y20=st_data(.,"wage","select21")
y10=log(y10)
y20=log(y20)
w10=st_data(.,"eweight","select11")
w20=st_data(.,"eweight","select21")
ev=uniqrows(sort(y10\y20,1))'
//point estimates
fh=fopen("${results}women_logit","r")
men_logit=fgetmatrix(fh)
fclose(fh)
q79=men_logit[.,1]
q88=men_logit[.,2]
qc1=men_logit[.,3]
qc2=men_logit[.,4]
qc3=men_logit[.,5]
//bootstrap
fh=fopen("${results}bootw","r")
a=fgetmatrix(fh)
q79b=q88b=qc1b=qc2b=qc3b=J(0,961,.)
while(rows(a)>1){
	q79b=q79b\a[.,1]'
	q88b=q88b\a[.,2]'
	qc1b=qc1b\a[.,3]'
	qc2b=qc2b\a[.,4]'
	qc3b=qc3b\a[.,5]'
	a=fgetmatrix(fh)
}
//smoothing of the quantile effects
quantile = (20..980)'/1000
q88s=q88
q79s=q79
qc1s=qc1
qc2s=qc2
qc3s=qc3
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88s[i]=mean(q88,wq)
	q79s[i]=mean(q79,wq)
	qc1s[i]=mean(qc1,wq)
	qc2s[i]=mean(qc2,wq)
	qc3s[i]=mean(qc3,wq)
}
q88bs=q79bs=qc1bs=qc2bs=qc3bs=q88b
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88bs[.,i]=mean(q88b',wq)'
	q79bs[.,i]=mean(q79b',wq)'
	qc1bs[.,i]=mean(qc1b',wq)'
	qc2bs[.,i]=mean(qc2b',wq)'
	qc3bs[.,i]=mean(qc3b',wq)'
}

//uniform confidence bands
tot=ev_boot(q88bs-q79bs,q88s'-q79s',(20..980)'/1000,0.98,0.02,95,a=.)
min=ev_boot(q88bs-qc1bs,q88s'-qc1s',(20..980)'/1000,0.98,0.02,95,a=.)
uni=ev_boot(qc1bs-qc2bs,qc1s'-qc2s',(20..980)'/1000,0.98,0.02,95,a=.)
char=ev_boot(qc2bs-qc3bs,qc2s'-qc3s',(20..980)'/1000,0.98,0.02,95,a=.)
coef=ev_boot(qc3bs-q79bs,qc3s'-q79s',(20..980)'/1000,0.98,0.02,95,a=.)

st_addvar("double", ("tots", "tots_lb", "tots_ub", "tots_se", "mins", "mins_lb", "mins_ub", "mins_se", "unis", "unis_lb", "unis_ub", "unis_se", "chars", "chars_lb", "chars_ub", "chars_se", "coefs", "coefs_lb", "coefs_ub", "coefs_se", "q88s", "q79s", "quantile"))
st_store((1..961)',"tots",q88s-q79s)
st_store((1..961)',"tots_lb",tot[.,2])
st_store((1..961)',"tots_ub",tot[.,3])
st_store((1..961)',"tots_se",tot[.,1])
st_store((1..961)',"mins",q88s-qc1s)
st_store((1..961)',"mins_lb",min[.,2])
st_store((1..961)',"mins_ub",min[.,3])
st_store((1..961)',"mins_se",min[.,1])
st_store((1..961)',"unis",qc1s-qc2s)
st_store((1..961)',"unis_lb",uni[.,2])
st_store((1..961)',"unis_ub",uni[.,3])
st_store((1..961)',"unis_se",uni[.,1])
st_store((1..961)',"chars",qc2s-qc3s)
st_store((1..961)',"chars_lb",char[.,2])
st_store((1..961)',"chars_ub",char[.,3])
st_store((1..961)',"chars_se",char[.,1])
st_store((1..961)',"coefs",qc3s-q79s)
st_store((1..961)',"coefs_lb",coef[.,2])
st_store((1..961)',"coefs_ub",coef[.,3])
st_store((1..961)',"coefs_se",coef[.,1])
st_store((1..961)',"q88s",q88s)
st_store((1..961)',"q79s",q79s)
st_store((1..961)',"quantile",quantile)
st_addvar("double", ("qc1s", "qc2s", "qc3s"))
st_store((1..961)',"qc1s",qc1s)
st_store((1..961)',"qc2s",qc2s)
st_store((1..961)',"qc3s",qc3s)
end

set scheme s1color
twoway (line q88s  quantile in 1/961) (line q79s  quantile in 1/961), ytitle(Quantiles) legend(order(1 "1988" 2 "1979") position(4) ring(0) rows(2)) xtitle("") title("Observed quantile functions") name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea tots_lb tots_ub quantile in 1/961, bcolor(ltblue)) (line tots quantile in 1/961, lcolor(edkblue)), legend(off) ytitle(QE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw ylabel(-0.3 -0.2 -0.1 0 0.1 0.2, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea mins_lb mins_ub quantile in 1/961, bcolor(ltblue)) (line mins quantile in 1/961, lcolor(edkblue)), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(men_min, replace) nodraw ylabel(-0.3 -0.2 -0.1 0 0.1 0.2, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea unis_lb unis_ub quantile in 1/961, bcolor(ltblue)) (line unis quantile in 1/961, lcolor(edkblue)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw  ylabel(-0.3 -0.2 -0.1 0 0.1 0.2, grid gmin gmax) ysc(r(-0.3 0.15))
twoway (rarea chars_lb chars_ub quantile in 1/961, bcolor(ltblue)) (line chars quantile in 1/961, lcolor(edkblue)), legend(size(large) order(2 "QE") region(style(none))) ytitle(QE) xtitle(Quantile) title("Composition") name(men_char, replace) nodraw fysize(45) ylabel(-0.3 -0.2 -0.1 0 0.1 0.2, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea coefs_lb coefs_ub quantile in 1/961, bcolor(ltblue)) (line coefs quantile in 1/961, lcolor(edkblue)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Quantile) title("Wage structure") name(men_resid, replace) nodraw fysize(45) ylabel(-0.3 -0.2 -0.1 0 0.1 0.2, gmin gmax grid) ysc(r(-0.3 0.15))
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/FigureC3.eps", replace
graph export "${graphs}/FigureC3.emf", replace

set scheme s1mono
twoway (line q88s  quantile in 1/961) (line q79s  quantile in 1/961), ytitle(Quantiles) legend(order(1 "1988" 2 "1979") position(4) ring(0) rows(2)) xtitle("") title("Observed quantile functions") name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea tots_lb tots_ub quantile in 1/961, bcolor(gs8)) (line tots quantile in 1/961, lcolor(gs1)), legend(off) ytitle(QE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw ylabel(-0.3 -0.2 -0.1 0 0.1 0.2, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea mins_lb mins_ub quantile in 1/961, bcolor(gs8)) (line mins quantile in 1/961, lcolor(gs1)), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(men_min, replace) nodraw ylabel(-0.3 -0.2 -0.1 0 0.1 0.2, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea unis_lb unis_ub quantile in 1/961, bcolor(gs8)) (line unis quantile in 1/961, lcolor(gs1)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw  ylabel(-0.3 -0.2 -0.1 0 0.1 0.2, grid gmin gmax) ysc(r(-0.3 0.15))
twoway (rarea chars_lb chars_ub quantile in 1/961, bcolor(gs8)) (line chars quantile in 1/961, lcolor(gs1)), legend(size(large) order(2 "QE") region(style(none))) ytitle(QE) xtitle(Quantile) title(Composition) name(men_char, replace) nodraw fysize(45) ylabel(-0.3 -0.2 -0.1 0 0.1 0.2, gmin gmax grid) ysc(r(-0.3 0.15))
twoway (rarea coefs_lb coefs_ub quantile in 1/961, bcolor(gs8)) (line coefs quantile in 1/961, lcolor(gs1)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Quantile) title(Wage structure) name(men_resid, replace) nodraw fysize(45) ylabel(-0.3 -0.2 -0.1 0 0.1 0.2, gmin gmax grid) ysc(r(-0.3 0.15))
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/FigureC3_bw.eps", replace
graph export "${graphs}/FigureC3_bw.emf", replace

*Figure C4
mata
d88=wdist(q88,1,ev)
d79=wdist(q79,1,ev)
dc1=wdist(qc1,1,ev)
dc2=wdist(qc2,1,ev)
dc3=wdist(qc3,1,ev)
d79b=d88b=dc1b=dc2b=dc3b=J(rows(q79b),cols(d88),.)
d88b=J(rows(q79b),cols(d88),.)
for(i=1;i<=rows(q79b);i++){
	d79b[i,.]=wdist(q79b[i,.]',1,ev)
	d88b[i,.]=wdist(q88b[i,.]',1,ev)
	dc1b[i,.]=wdist(qc1b[i,.]',1,ev)
	dc2b[i,.]=wdist(qc2b[i,.]',1,ev)
	dc3b[i,.]=wdist(qc3b[i,.]',1,ev)
}
d88s=d79s=dc1s=dc2s=dc3s=dc3
for(i=1;i<=5704;i++){
wq=mm_kern("gaussian",(ev:-ev[i]):/0.015)'
d88s[i]=mean(d88',wq)
d79s[i]=mean(d79',wq)
dc1s[i]=mean(dc1',wq)
dc2s[i]=mean(dc2',wq)
dc3s[i]=mean(dc3',wq)
}
d88bs=d79bs=dc1bs=dc2bs=dc3bs=d88b
for(i=1;i<=5704;i++){
	wq=mm_kern("gaussian",(ev:-ev[i]):/0.015)'
	d88bs[.,i]=mean(d88b',wq)'
	d79bs[.,i]=mean(d79b',wq)'
	dc1bs[.,i]=mean(dc1b',wq)'
	dc2bs[.,i]=mean(dc2b',wq)'
	dc3bs[.,i]=mean(dc3b',wq)'
}
tot_band=ev_boot(d88bs-d79bs,d88s-d79s,(d79s',d88s'),0.98,0.02,95,ttot=.)
min_band=ev_boot(d88bs-dc1bs,d88s-dc1s,(dc1s',d88s'),0.98,0.02,95,tmin=.)
uni_band=ev_boot(dc1bs-dc2bs,dc1s-dc2s,(dc2s',dc1s'),0.98,0.02,95,tuni=.)
char_band=ev_boot(dc2bs-dc3bs,dc2s-dc3s,(dc3s',dc2s'),0.98,0.02,95,tchar=.)
coef_band=ev_boot(dc3bs-d79bs,dc3s-d79s,(d79s',dc3s'),0.98,0.02,95,tcoef=.)
st_addvar("double", ("dtots", "dtots_lb", "dtots_ub","dmins","dmins_lb","dmins_ub","dunis","dunis_lb","dunis_ub","dchars","dchars_lb","dchars_ub","dcoefs","dcoefs_lb","dcoefs_ub","d79s","d88s","dc1s","dc2s","dc3s","ev"))
st_store((1..5704)',"dtots",d88s'-d79s')
st_store((1..5704)',"dtots_lb",tot_band[.,2])
st_store((1..5704)',"dtots_ub",tot_band[.,3])
st_store((1..5704)',"dmins",d88s'-dc1s')
st_store((1..5704)',"dmins_lb",min_band[.,2])
st_store((1..5704)',"dmins_ub",min_band[.,3])
st_store((1..5704)',"dunis",dc1s'-dc2s')
st_store((1..5704)',"dunis_lb",uni_band[.,2])
st_store((1..5704)',"dunis_ub",uni_band[.,3])
st_store((1..5704)',"dchars",dc2s'-dc3s')
st_store((1..5704)',"dchars_lb",char_band[.,2])
st_store((1..5704)',"dchars_ub",char_band[.,3])
st_store((1..5704)',"dcoefs",dc3s'-d79s')
st_store((1..5704)',"dcoefs_lb",coef_band[.,2])
st_store((1..5704)',"dcoefs_ub",coef_band[.,3])
st_store((1..5704)',"d79s",d79s')
st_store((1..5704)',"d88s",d88s')
st_store((1..5704)',"ev",ev')
st_store((1..5704)',"dc1s",dc1s')
st_store((1..5704)',"dc2s",dc2s')
st_store((1..5704)',"dc3s",dc3s')
end

set scheme s1mono
twoway (line d88s ev if ev>0.5 & ev<2.6) (line d79s ev if ev>0.5 & ev<2.6), ytitle(CDFs) legend(order(1 "1988" 2 "1979") position(4) ring(0) rows(2)) xtitle("") title(Observed distribution functions) name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea dtots_lb dtots_ub ev if ev>0.5 & ev<2.6, bcolor(gs5)) (line dtots ev if ev>0.5 & ev<2.6, lcolor(gs1)), legend(off) ytitle(DE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw yscale(range(-0.15 0.15)) ylabel(-0.1 0 0.1, gmax gmin grid)
twoway (rarea dmins_lb dmins_ub ev if ev>0.5 & ev<2.6, bcolor(gs5)) (line dmins ev if ev>0.5 & ev<2.6, lcolor(gs1)), legend(off) xtitle("") ytitle(DE) title(Minimum wage) name(men_min, replace) nodraw yscale(range(-0.15 0.15)) ylabel(-0.1 0 0.1, gmax gmin grid)
twoway (rarea dunis_lb dunis_ub ev if ev>0.5 & ev<2.6, bcolor(gs5)) (line dunis ev if ev>0.5 & ev<2.6, lcolor(gs1)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw yscale(range(-0.15 0.15)) ylabel(-0.1 0 0.1, gmax gmin grid)
twoway (rarea dchars_lb dchars_ub ev if ev>0.5 & ev<2.6, bcolor(gs5)) (line dchars ev if ev>0.5 & ev<2.6, lcolor(gs1)), legend(size(large) order(2 "DE") region(style(none))) ytitle(DE) xtitle(Log real wage) title(Composition) name(men_char, replace) nodraw fysize(45) yscale(range(-0.15 0.15)) ylabel(-0.1 0 0.1, gmax gmin grid)
twoway (rarea dcoefs_lb dcoefs_ub ev if ev>0.5 & ev<2.6, bcolor(gs5)) (line dcoefs ev if ev>0.5 & ev<2.6, lcolor(gs1)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Log real wage) title(Wage structure) name(men_resid, replace) nodraw fysize(45) yscale(range(-0.15 0.15)) ylabel(-0.1 0 0.1, gmax gmin grid)
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/FigureC4_bw.eps", replace
graph export "${graphs}/FigureC4_bw.emf", replace

set scheme s1color
twoway (line d88s ev if ev>0.7 & ev<3) (line d79s ev if ev>0.7 & ev<3), ytitle(CDFs) legend(order(1 "1988" 2 "1979") position(4) ring(0) rows(2)) xtitle("") title(Observed distribution functions) name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea dtots_lb dtots_ub ev if ev>0.7 & ev<3, bcolor(ltblue)) (line dtots ev if ev>0.7 & ev<3, lcolor(edkblue)), legend(off) ytitle(DE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw yscale(range(-0.15 0.15)) ylabel(-0.1 0 0.1, gmax gmin grid)
twoway (rarea dmins_lb dmins_ub ev if ev>0.7 & ev<3, bcolor(ltblue)) (line dmins ev if ev>0.7 & ev<3, lcolor(edkblue)), legend(off) xtitle("") ytitle(DE) title(Minimum wage) name(men_min, replace) nodraw yscale(range(-0.15 0.15)) ylabel(-0.1 0 0.1, gmax gmin grid)
twoway (rarea dunis_lb dunis_ub ev if ev>0.7 & ev<3, bcolor(ltblue)) (line dunis ev if ev>0.7 & ev<3, lcolor(edkblue)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw yscale(range(-0.15 0.15)) ylabel(-0.1 0 0.1, gmax gmin grid)
twoway (rarea dchars_lb dchars_ub ev if ev>0.7 & ev<3, bcolor(ltblue)) (line dchars ev if ev>0.7 & ev<3, lcolor(edkblue)), legend(size(large) order(2 "DE") region(style(none))) ytitle(DE) xtitle(Log real wage) title(Composition) name(men_char, replace) nodraw fysize(45) yscale(range(-0.15 0.15)) ylabel(-0.1 0 0.1, gmax gmin grid)
twoway (rarea dcoefs_lb dcoefs_ub ev if ev>0.7 & ev<3, bcolor(ltblue)) (line dcoefs ev if ev>0.7 & ev<3, lcolor(edkblue)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Log real wage) title(Wage structure) name(men_resid, replace) nodraw fysize(45) yscale(range(-0.15 0.15)) ylabel(-0.1 0 0.1, gmax gmin grid)
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/FigureC4.eps", replace
graph export "${graphs}/FigureC4.emf", replace

*Figure C5
mata
l88=runningsum(exp(q88))':/sum(exp(q88))
l79=runningsum(exp(q79))':/sum(exp(q79))
lc1=runningsum(exp(qc1))':/sum(exp(qc1))
lc2=runningsum(exp(qc2))':/sum(exp(qc2))
lc3=runningsum(exp(qc3))':/sum(exp(qc3))
l79b=l88b=lc1b=lc2b=lc3b=J(rows(q79b),cols(l88),.)
for(i=1;i<=rows(q79b);i++){
	l79b[i,.]=runningsum(exp(q79b[i,.])):/sum(exp(q79b[i,.]))
	l88b[i,.]=runningsum(exp(q88b[i,.])):/sum(exp(q88b[i,.]))
	lc1b[i,.]=runningsum(exp(qc1b[i,.])):/sum(exp(qc1b[i,.]))
	lc2b[i,.]=runningsum(exp(qc2b[i,.])):/sum(exp(qc2b[i,.]))
	lc3b[i,.]=runningsum(exp(qc3b[i,.])):/sum(exp(qc3b[i,.]))
}
st_addvar("double", ("l79","l88","lc1","lc2","lc3"))
st_store((1..961)',"l79",l79')
st_store((1..961)',"l88",l88')
st_store((1..961)',"lc1",lc1')
st_store((1..961)',"lc2",lc2')
st_store((1..961)',"lc3",lc3')
st_addvar("double", ("ltot", "ltot_lb", "ltot_ub", "ltot_se", "lmin", "lmin_lb", "lmin_ub", "lmin_se", "luni", "luni_lb", "luni_ub", "luni_se", "lchar", "lchar_lb", "lchar_ub", "lchar_se", "lcoef", "lcoef_lb", "lcoef_ub", "lcoef_se"))
tot=ev_boot(l88b-l79b, l88-l79, (20..980)'/1000, 0.97, 0.03, 95, a=.)
st_store((1..961)',"ltot",l88'-l79')
st_store((1..961)',"ltot_lb",tot[.,2])
st_store((1..961)',"ltot_ub",tot[.,3])
st_store((1..961)',"ltot_se",tot[.,1])
tot=ev_boot(l88b-lc1b,l88-lc1,(20..980)'/1000, 0.97, 0.03, 95,a=.)
st_store((1..961)',"lmin",l88'-lc1')
st_store((1..961)',"lmin_lb",tot[.,2])
st_store((1..961)',"lmin_ub",tot[.,3])
st_store((1..961)',"lmin_se",tot[.,1])
tot=ev_boot(lc1b-lc2b,lc1-lc2,(20..980)'/1000, 0.97, 0.03, 95,a=.)
st_store((1..961)',"luni",lc1'-lc2')
st_store((1..961)',"luni_lb",tot[.,2])
st_store((1..961)',"luni_ub",tot[.,3])
st_store((1..961)',"luni_se",tot[.,1])
tot=ev_boot(lc2b-lc3b,lc2-lc3,(20..980)'/1000, 0.97, 0.03, 95,a=.)
st_store((1..961)',"lchar",lc2'-lc3')
st_store((1..961)',"lchar_lb",tot[.,2])
st_store((1..961)',"lchar_ub",tot[.,3])
st_store((1..961)',"lchar_se",tot[.,1])
tot=ev_boot(lc3b-l79b,lc3-l79,(20..980)'/1000, 0.97, 0.03, 95,a=.)
st_store((1..961)',"lcoef",lc3'-l79')
st_store((1..961)',"lcoef_lb",tot[.,2])
st_store((1..961)',"lcoef_ub",tot[.,3])
st_store((1..961)',"lcoef_se",tot[.,1])
end

set scheme s1mono
twoway (line l88 quantile in 1/961) (line l79 quantile in 1/961), ytitle(Observed Lorenz curves) legend(order(1 "1988" 2 "1979") rows(2) position(4) ring(0)) xtitle("") title(Lorenz curves) name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea ltot_lb ltot_ub quantile if quantile>0.02 & quantile<0.98, bcolor(gs5)) (line ltot quantile if quantile>0.02 & quantile<0.98, lcolor(gs1)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) ytitle(LE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid) yscale(range(-0.047 0))
twoway (rarea lmin_lb lmin_ub quantile if quantile>0.02 & quantile<0.98, bcolor(gs5)) (line lmin quantile if quantile>0.02 & quantile<0.98, lcolor(gs1)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) xtitle("") ytitle(LE) title(Minimum wage) name(men_min, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid) yscale(range(-0.047 0))
twoway (rarea luni_lb luni_ub quantile if quantile>0.02 & quantile<0.98, bcolor(gs5)) (line luni quantile if quantile>0.02 & quantile<0.98, lcolor(gs1)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid) yscale(range(-0.047 0))
twoway (rarea lchar_lb lchar_ub quantile if quantile>0.02 & quantile<0.98, bcolor(gs5)) (line lchar quantile if quantile>0.02 & quantile<0.98, lcolor(gs1)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(size(large) order(2 "LE") region(style(none))) ytitle(LE) xtitle(Quantile) title(Composition) name(men_char, replace) nodraw fysize(45) ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid) yscale(range(-0.047 0))
twoway (rarea lcoef_lb lcoef_ub quantile if quantile>0.02 & quantile<0.98, bcolor(gs5)) (line lcoef quantile if quantile>0.02 & quantile<0.98, lcolor(gs1)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Quantile) title(Wage structure) name(men_resid, replace) nodraw fysize(45) ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid) yscale(range(-0.047 0))
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/FigureC5_bw.eps", replace
graph export "${graphs}/FigureC5_bw.emf", replace

set scheme s1color
twoway (line l88 quantile in 1/961) (line l79 quantile in 1/961), ytitle(Observed Lorenz curves) legend(order(1 "1988" 2 "1979") rows(2) position(4) ring(0)) xtitle("") title(Lorenz curves) name(men_qfunc, replace) nodraw ylabel(,grid)
twoway (rarea ltot_lb ltot_ub quantile if quantile>0.02 & quantile<0.98, bcolor(ltblue)) (line ltot quantile if quantile>0.02 & quantile<0.98, lcolor(edkblue)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) ytitle(LE) xtitle("") title(Observed differences) name(men_tot, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid) yscale(range(-0.047 0))
twoway (rarea lmin_lb lmin_ub quantile if quantile>0.02 & quantile<0.98, bcolor(ltblue)) (line lmin quantile if quantile>0.02 & quantile<0.98, lcolor(edkblue)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) xtitle("") ytitle(LE) title(Minimum wage) name(men_min, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid) yscale(range(-0.047 0))
twoway (rarea luni_lb luni_ub quantile if quantile>0.02 & quantile<0.98, bcolor(ltblue)) (line luni quantile if quantile>0.02 & quantile<0.98, lcolor(edkblue)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(off) xtitle("") ytitle("") title(De-unionization) name(men_uni, replace) nodraw ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid) yscale(range(-0.047 0))
twoway (rarea lchar_lb lchar_ub quantile if quantile>0.02 & quantile<0.98, bcolor(ltblue)) (line lchar quantile if quantile>0.02 & quantile<0.98, lcolor(edkblue)) (line lcoef_ub quantile if quantile>0.02 & quantile<0.98, lcolor(none)), legend(size(large) order(2 "LE") region(style(none))) ytitle(LE) xtitle(Quantile) title(Composition) name(men_char, replace) nodraw fysize(45) ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid) yscale(range(-0.047 0))
twoway (rarea lcoef_lb lcoef_ub quantile if quantile>0.02 & quantile<0.98, bcolor(ltblue)) (line lcoef quantile if quantile>0.02 & quantile<0.98, lcolor(edkblue)), legend(size(large) order(1 "Uniform confidence bands") region(style(none)) rows(1)) xtitle(Quantile) title(Wage structure) name(men_resid, replace) nodraw fysize(45) ylabel(-0.04 -0.03 -0.02 -0.01 0, gmin gmax grid) yscale(range(-0.047 0))
graph combine men_qfunc men_tot men_min men_uni men_char men_resid, rows(3) imargin(tiny) xsize(8) ysize(10) iscale(0.55)
graph export "${graphs}/FigureC5.eps", replace
graph export "${graphs}/FigureC5.emf", replace

*Table C4
mata table(q88,q79,qc1,qc2,qc3,q88b,q79b,qc1b,qc2b,qc3b,"tableC4")
mat list tableC4

*Figure C6
mata
mata drop res_logit res_prob res_lpm res_cauchit res_loglog
mata matuse "${results}w_compare_dr.dta"
st_addvar("double", ("mw_l", "mw_p", "mw_lin", "mw_c", "mw_loglog", "union_l", "union_p", "union_lin", "union_c", "union_loglog", "char_l", "char_p", "char_lin", "char_c", "char_loglog", "coef_l", "coef_p", "coef_lin", "coef_c", "coef_loglog"))
//smoothing
res_logits=res_logit
res_probs=res_prob
res_lpms=res_lpm
res_cauchits=res_cauchit
res_loglogs=res_loglog
for(i=1;i<=961;i++){
	for(c=1;c<=5;c++){
		wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
		res_logits[i,c]=mean(res_logit[,c],wq)
		res_probs[i,c]=mean(res_prob[,c],wq)
		res_lpms[i,c]=mean(res_lpm[,c],wq)
		res_cauchits[i,c]=mean(res_cauchit[,c],wq)
		res_loglogs[i,c]=mean(res_loglog[,c],wq)
	}
}
st_store((1..961)',"mw_l",res_logits[,2]:-res_logits[,3])
st_store((1..961)',"mw_p",res_probs[,2]:-res_probs[,3])
st_store((1..961)',"mw_lin",res_lpms[,2]:-res_lpms[,3])
st_store((1..961)',"mw_c",res_cauchits[,2]:-res_cauchits[,3])
st_store((1..961)',"mw_loglog",res_loglogs[,2]:-res_loglogs[,3])
st_store((1..961)',"union_l",res_logits[,3]:-res_logits[,4])
st_store((1..961)',"union_p",res_probs[,3]:-res_probs[,4])
st_store((1..961)',"union_lin",res_lpms[,3]:-res_lpms[,4])
st_store((1..961)',"union_c",res_cauchits[,3]:-res_cauchits[,4])
st_store((1..961)',"union_loglog",res_loglogs[,3]:-res_loglogs[,4])
st_store((1..961)',"char_l",res_logits[,4]:-res_logits[,5])
st_store((1..961)',"char_p",res_probs[,4]:-res_probs[,5])
st_store((1..961)',"char_lin",res_lpms[,4]:-res_lpms[,5])
st_store((1..961)',"char_c",res_cauchits[,4]:-res_cauchits[,5])
st_store((1..961)',"char_loglog",res_loglogs[,4]:-res_loglogs[,5])
st_store((1..961)',"coef_l",res_logits[,5]:-res_logits[,1])
st_store((1..961)',"coef_p",res_probs[,5]:-res_probs[,1])
st_store((1..961)',"coef_lin",res_lpms[,5]:-res_lpms[,1])
st_store((1..961)',"coef_c",res_cauchits[,5]:-res_cauchits[,1])
st_store((1..961)',"coef_loglog",res_loglogs[,5]:-res_loglogs[,1])
end

set scheme s1color
twoway (line mw_l quantile, lp(shortdash)) (line mw_p quantile, lp(shortdash)) (line mw_lin quantile) (line mw_c quantile) (line mw_loglog quantile), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(comp_min, replace) nodraw ylabel(-0.2 -0.1 0 0.1, grid) yscale(range(-0.25 0.17))
twoway (line union_l quantile, lp(shortdash)) (line union_p quantile, lp(shortdash)) (line union_lin quantile) (line union_c quantile) (line union_loglog quantile), legend(off) xtitle("") ytitle("") title(De-unionization) name(comp_uni, replace) nodraw ylabel(-0.2 -0.1 0 0.1, grid) yscale(range(-0.25 0.17))
twoway (line char_l quantile, lp(shortdash)) (line char_p quantile, lp(shortdash)) (line char_lin quantile) (line char_c quantile) (line char_loglog quantile), legend(symxsize(3) order(1 "Logit" 3 "Linear probability model" 5 "Complementary log-log") rows(3) region(style(none))) ytitle(QE) xtitle(Quantile) title(Composition) name(comp_char, replace) nodraw fysize(56) ylabel(-0.2 -0.1 0 0.1, grid) yscale(range(-0.25 0.17))
twoway (line coef_l quantile, lp(shortdash)) (line coef_p quantile, lp(shortdash)) (line coef_lin quantile) (line coef_c quantile) (line coef_loglog quantile), legend(symxsize(5) order(2 "Probit" 4 "Cauchit" - " ") region(style(none)) rows(3)) xtitle(Quantile) title(Wage structure) name(comp_resid, replace) nodraw fysize(56) ylabel(-0.2 -0.1 0 0.1, grid) yscale(range(-0.25 0.17))
graph combine comp_min comp_uni comp_char comp_resid, rows(2) imargin(tiny) xsize(8) ysize(8)
graph export "${graphs}FigureC6.eps", replace
graph export "${graphs}FigureC6.emf", replace

set scheme s1mono
twoway (line mw_l quantile, lc(black)) (line mw_p quantile, lp(shortdash) lc(black)) (line mw_lin quantile, lc(gs8) lp(solid)) (line mw_c quantile, lp(shortdash) lc(gs8)) (line mw_loglog quantile, lc(black) lp(". .")), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(comp_min, replace) nodraw ylabel(-0.2 -0.1 0 0.1, grid) yscale(range(-0.25 0.17))
twoway (line union_l quantile, lc(black)) (line union_p quantile, lp(shortdash) lc(black)) (line union_lin quantile, lc(gs8) lp(solid)) (line union_c quantile, lp(shortdash) lc(gs8)) (line union_loglog quantile, lc(black) lp(". .")), legend(off) xtitle("") ytitle("") title(De-unionization) name(comp_uni, replace) nodraw ylabel(-0.2 -0.1 0 0.1, grid) yscale(range(-0.25 0.17))
twoway (line char_l quantile, lc(black)) (line char_p quantile, lp(shortdash) lc(black)) (line char_lin quantile, lc(gs8) lp(solid)) (line char_c quantile, lp(shortdash) lc(gs8)) (line char_loglog quantile, lc(black) lp(". .")), legend(symxsize(3) order(1 "Logit" 3 "Linear probability model" 5 "Complementary log-log") rows(3) region(style(none))) ytitle(QE) xtitle(Quantile) title(Composition) name(comp_char, replace) nodraw fysize(56) ylabel(-0.2 -0.1 0 0.1, grid) yscale(range(-0.25 0.17))
twoway (line coef_l quantile, lc(black)) (line coef_p quantile, lp(shortdash) lc(black)) (line coef_lin quantile, lc(gs8) lp(solid)) (line coef_c quantile, lp(shortdash) lc(gs8)) (line coef_loglog quantile, lc(black) lp(". .")), legend(symxsize(5) order(2 "Probit" 4 "Cauchit" - " ") region(style(none)) rows(3)) xtitle(Quantile) title(Wage structure) name(comp_resid, replace) nodraw fysize(56) ylabel(-0.2 -0.1 0 0.1, grid) yscale(range(-0.25 0.17))
graph combine comp_min comp_uni comp_char comp_resid, rows(2) imargin(tiny) xsize(8) ysize(8)
graph export "${graphs}FigureC6_bw.eps", replace
graph export "${graphs}FigureC6_bw.emf", replace

*Table C5
mata
//Censored distribution regression
//censoring the estimates
q79=rowmax((q79,J(961,1,1.098612309)))
q88=rowmax((q88,J(961,1,.7923135757)))
qc1=rowmax((qc1,J(961,1,1.098612309)))
qc2=rowmax((qc2,J(961,1,1.098612309)))
qc3=rowmax((qc3,J(961,1,1.098612309)))
for(j=1;j<=rows(q88b);j++){
	q79b[j,.]=rowmax((q79b[j,.]',J(961,1,1.098612309)))'
	q88b[j,.]=rowmax((q88b[j,.]',J(961,1,.7923135757)))'
	qc1b[j,.]=rowmax((qc1b[j,.]',J(961,1,1.098612309)))'
	qc2b[j,.]=rowmax((qc2b[j,.]',J(961,1,1.098612309)))'
	qc3b[j,.]=rowmax((qc3b[j,.]',J(961,1,1.098612309)))'
}
//smoothing 
q88s=q79s=qc1s=qc2s=qc3s=qc3
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88s[i]=mean(q88,wq)
	q79s[i]=mean(q79,wq)
	qc1s[i]=mean(qc1,wq)
	qc2s[i]=mean(qc2,wq)
	qc3s[i]=mean(qc3,wq)
}
q88bs=q79bs=qc1bs=qc2bs=qc3bs=q88b
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88bs[.,i]=mean(q88b',wq)'
	q79bs[.,i]=mean(q79b',wq)'
	qc1bs[.,i]=mean(qc1b',wq)'
	qc2bs[.,i]=mean(qc2b',wq)'
	qc3bs[.,i]=mean(qc3b',wq)'
}
//First part of table C5
table(q88,q79,qc1,qc2,qc3,q88b,q79b,qc1b,qc2b,qc3b,"tableC5a")
end
mat list tableC5a
//generating the variables for Figure C2
mata
st_addvar("double", ("mincs", "unics", "charcs", "coefcs"))
st_store((1..961)',"mincs",q88s-qc1s)
st_store((1..961)',"unics",qc1s-qc2s)
st_store((1..961)',"charcs",qc2s-qc3s)
st_store((1..961)',"coefcs",qc3s-q79s)
end

//Censored quantile regression
mata
fh=fopen("${results}women_cqr","r")
men_qr=fgetmatrix(fh)
fclose(fh)
q79=men_qr[.,3]
q88=men_qr[.,4]
qc1=men_qr[.,5]
qc2=men_qr[.,6]
qc3=men_qr[.,7]
fh=fopen("${results}boot_women_cqr","r")
a=fgetmatrix(fh)
q79b=q88b=qc1b=qc2b=qc3b=J(0,961,.)
while(rows(a)>1){
	q79b=q79b\a[.,3]'
	q88b=q88b\a[.,4]'
	qc1b=qc1b\a[.,5]'
	qc2b=qc2b\a[.,6]'
	qc3b=qc3b\a[.,7]'
	a=fgetmatrix(fh)
}
fclose(fh)
//Second part of table C5
table(q88,q79,qc1,qc2,qc3,q88b,q79b,qc1b,qc2b,qc3b,"tableC5b")
end
mat list tableC5b
//generating the variables for Figure C7
mata
st_addvar("double", ("totcqr", "mincqr", "unicqr", "charcqr", "coefcqr"))
st_store((1..961)',"totcqr",q88-q79)
st_store((1..961)',"mincqr",q88-qc1)
st_store((1..961)',"unicqr",qc1-qc2)
st_store((1..961)',"charcqr",qc2-qc3)
st_store((1..961)',"coefcqr",qc3-q79)
end

*Figure C2
set scheme s1mono
twoway (line mins quantile, lc(black)) (line mincs quantile, lp(shortdash) lc(black)) (line mincqr quantile, lc(gs8) lp(solid)), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(comp_min, replace) nodraw ylabel(, grid)
twoway (line unis quantile, lc(black)) (line unics quantile, lp(shortdash) lc(black)) (line unicqr quantile, lc(gs8) lp(solid)), legend(off) xtitle("") ytitle("") title(De-unionization) name(comp_uni, replace) nodraw ylabel(, grid)
twoway (line chars quantile, lc(black)) (line charcs quantile, lp(shortdash) lc(black)) (line charcqr quantile, lc(gs8) lp(solid)), legend(symxsize(3) order(1 "Distribution regression" 3 "Censored quantile regression") rows(2) region(style(none))) ytitle(QE) xtitle(Quantile) title(Composition) name(comp_char, replace) nodraw fysize(52) ylabel(, grid)
twoway (line coefs quantile, lc(black)) (line coefcs quantile, lp(shortdash) lc(black)) (line coefcqr quantile, lc(gs8) lp(solid)) , legend(symxsize(5) order(2 "Censored distribution regression" 4 "") region(style(none)) rows(2) rowgap(4)) xtitle(Quantile) title(Wage structure) name(comp_resid, replace) nodraw fysize(52) ylabel(, grid)
graph combine comp_min comp_uni comp_char comp_resid, ycommon rows(2) imargin(tiny) xsize(8) ysize(8)
graph export "${graphs}FigureC7_bw.eps", replace
graph export "${graphs}FigureC7_bw.emf", replace

set scheme s1color
twoway (line mins quantile, lp(shortdash)) (line mincs quantile) (line mincqr quantile), legend(off) xtitle("") ytitle(QE) title(Minimum wage) name(comp_min, replace) nodraw ylabel(, grid)
twoway (line unis quantile, lp(shortdash)) (line unics quantile) (line unicqr quantile), legend(off) xtitle("") ytitle("") title(De-unionization) name(comp_uni, replace) nodraw ylabel(, grid)
twoway (line chars quantile, lp(shortdash)) (line charcs quantile) (line charcqr quantile), legend(symxsize(3) order(1 "Distribution regression" 3 "Censored quantile regression") rows(2) region(style(none))) ytitle(QE) xtitle(Quantile) title(Composition) name(comp_char, replace) nodraw fysize(52) ylabel(, grid)
twoway (line coefs quantile, lp(shortdash)) (line coefcs quantile) (line coefcqr quantile) , legend(symxsize(5) order(2 "Censored distribution regression" 4 "") region(style(none)) rows(2) rowgap(4)) xtitle(Quantile) title(Wage structure) name(comp_resid, replace) nodraw fysize(52) ylabel(, grid)
graph combine comp_min comp_uni comp_char comp_resid, ycommon rows(2) imargin(tiny) xsize(8) ysize(8)
graph export "${graphs}FigureC7.eps", replace
graph export "${graphs}FigureC7.emf", replace

*Table C3 - women
mata
//point estimates
fh=fopen("${results}women_inv_logit","r")
men_logit=fgetmatrix(fh)
fclose(fh)
q79=men_logit[.,1]
q88=men_logit[.,2]
qc1=men_logit[.,3]
qc2=men_logit[.,4]
qc3=men_logit[.,5]
//bootstrap
fh=fopen("${results}boot_women_inv","r")
a=fgetmatrix(fh)
q79b=q88b=qc1b=qc2b=qc3b=J(0,961,.)
while(rows(a)>1){
	q79b=q79b\a[.,1]'
	q88b=q88b\a[.,2]'
	qc1b=qc1b\a[.,3]'
	qc2b=qc2b\a[.,4]'
	qc3b=qc3b\a[.,5]'
	a=fgetmatrix(fh)
}
fclose(fh)
//smoothing of the quantile effects
quantile = (20..980)'/1000
q88s=q79s=qc1s=qc2s=qc3s=qc3
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88s[i]=mean(q88,wq)
	q79s[i]=mean(q79,wq)
	qc1s[i]=mean(qc1,wq)
	qc2s[i]=mean(qc2,wq)
	qc3s[i]=mean(qc3,wq)
}
q88bs=q79bs=qc1bs=qc2bs=qc3bs=q88b
for(i=1;i<=961;i++){
	wq=mm_kern("gaussian",(quantile:-quantile[i]):/0.015)
	q88bs[.,i]=mean(q88b',wq)'
	q79bs[.,i]=mean(q79b',wq)'
	qc1bs[.,i]=mean(qc1b',wq)'
	qc2bs[.,i]=mean(qc2b',wq)'
	qc3bs[.,i]=mean(qc3b',wq)'
}
table(q88,q79,qc1,qc2,qc3,q88b,q79b,qc1b,qc2b,qc3b,"tableC3b")
end
mat list tableC3b

*Table C1
use "${data}un79rw.dta", clear
gen wave=1
append using "${data}cps88.dta"
recode wave .=2
replace wage=wage*0.631 if wave==2
gen primary=(nind==1 | nind==2 | nind==20)
gen secondary=(nind==3 | nind==4 | nind==5)
gen tertiary=1-primary-secondary
count if wave==1 & female==0
mat tableC1=r(N)
count if wave==2 & female==0
mat tableC1=tableC1,r(N)
count if wave==1 & female==1
mat tableC1=tableC1,r(N)
count if wave==2 & female==1
mat tableC1=tableC1,r(N)
foreach x in wage educ exper union primary secondary tertiary partt nonwhite smsa {
	sum `x' if wave==1 & female==0
	mat temp=r(mean)
	mat temp1=r(sd)
	sum `x' if wave==2 & female==0
	mat temp=temp,r(mean)
	mat temp1=temp1,r(sd)
	sum `x' if wave==1 & female==1
	mat temp=temp,r(mean)
	mat temp1=temp1,r(sd)
	sum `x' if wave==2 & female==1
	mat temp=temp,r(mean)
	mat temp1=temp1,r(sd)
	mat tableC1=nullmat(tableC1)\temp\temp1
}
mata st_matrix("tableC1",(st_matrix("tableC1")[1,.]\round(st_matrix("tableC1")[2..7,.]:*100):/100\round(st_matrix("tableC1")[8..21,.]:*10000):/100))
mat list tableC1

