library(foreign)
library(corpcor)
library(snow)

#Data
#Change path! (data generated by the do-file "data preparation")
data=read.dta("C:/Users/Blaise/Dropbox/COUNTERFACTUAL/Replication files/Data/data.dta")
attach(data)
x=cbind(smsa,partt,nonwhite,exper,exper2,union,educ,educ^2)[female==0 & wave==2,]
y=logw[female==0 & wave==2]
w=eweight[female==0 & wave==2]
x_uncond=cbind(smsa,partt,nonwhite,exper,exper2,union,educ,educ^2)[female==0 & wave==1,]
detach(data)
rm(data)

#Function that generates the dependent variable
dgp=function(obs,type,xb=xb, p=0.5){
	if(type<5) yb=cbind(1,xb)%*%location[2:10]+rlogis(obs)*location[1]*3^0.5/pi
	if(type==5 | type==6) yb=cbind(1,xb)%*%location[2:10]+rt(obs,3)*location[1]/3^0.5
	if(type==7 | type==8) yb=cbind(1,xb)%*%location[2:10]+rt(obs,5)*location[1]/(5/3)^0.5
	if(type==9 | type==10 | type==14) yb=cbind(1,xb)%*%location+resid[ceiling(nrow(x) * runif(obs))]
	if(type==11 | type==12 | type==13 | type==15 | type==16) yb=cbind(1,xb)%*%location[1:9]+resid[ceiling(nrow(x) * runif(obs))]*pmax(cbind(1,xb)%*%location[10:18],0)^0.5
	if(type==17 | type==18) yb=cbind(1,xb)%*%location[1:9]+resid[ceiling(nrow(x) * runif(obs))]*exp(cbind(1,xb)%*%location[10:18])^0.5
	if(type==1 | type==14 | type==15 | type==18) yb=c(yb[1:ceiling(length(yb)*(1-p))],log(ceiling(exp(yb[(ceiling(length(yb)*(1-p))+1):length(yb)]))))
	if(type==2 | type==13) yb=c(yb[1:ceiling(length(yb)*(1-p))],log(0.5*ceiling(2*exp(yb[(ceiling(length(yb)*(1-p))+1):length(yb)]))))
	if(type==3 | type==16) yb=c(yb[1:ceiling(length(yb)*(1-p))],0.1*ceiling(10*yb[(ceiling(length(yb)*(1-p))+1):length(yb)]))
	if(type==4 | type==6 | type==8 | type==10 | type==12){
		for(i in 1:length(pround)){
			temp=(yb>=pcut[i,1])*(yb<=pcut[i,2])*rbinom(obs,1,pround[i])
			n=sum(temp)
			if(n>0) yb[temp==1]=uv_use[i+1]
		}
	}
	yb
}

#Function that calculates the true values (by numerical integration when there is no analytical solution)
true_value=function(type, nq, xeval,p=0.5){
	set.seed(1234)
	xb=x[ceiling(nrow(x) * runif(1000000)),]
	yb=dgp(1000000,type,xb,p)
	evald=unique(quantile(yb,evalq))
	estimd=sort(unique(c(evald,quantile(yb,seq(0.5/nq,1-0.5/nq,1/nq)))))
	index=c()
	for(i in 1:length(evald)) index=c(index,sum(estimd<=evald[i]))
	trued1=c()
	if(type==0) for(i in 1:length(evald)) trued1=c(trued1,plogis((evald[i]-cbind(1,xeval)%*%location[2:10])/location[1]/3^0.5*pi))
	if(type==1 | type==2 | type==3){
		yb=yb[(ceiling(length(yb)*(1-p))+1):length(yb)]
		evald1=sort(unique(yb))
		temp=matrix(,length(evald1),neval)
		for(i in 1:length(evald1)) temp[i,]=plogis((evald1[i]-cbind(1,xeval)%*%location[2:10])/location[1]/3^0.5*pi)
		for(i in 1:length(evald)) trued1=c(trued1,((1-p)*plogis((evald[i]-cbind(1,xeval)%*%location[2:10])/location[1]/3^0.5*pi)+p*temp[sum(evald1<=evald[i]),]))
	}
	if(type==5) for(i in 1:length(evald)) trued1=c(trued1,pt((evald[i]-cbind(1,xeval)%*%location[2:10])/location[1]*3^0.5,3))
	if(type==7) for(i in 1:length(evald)) trued1=c(trued1,pt((evald[i]-cbind(1,xeval)%*%location[2:10])/location[1]*(5/3)^0.5,5))
	if(type==9) for(i in 1:length(evald)) for(j in 1:nrow(xeval)) trued1=c(trued1,mean((matrix(c(1,xeval[j,]),1,9)%*%matrix(location)+c(resid))<=evald[i]))
	if(type==11) for(i in 1:length(evald)) for(j in 1:nrow(xeval)) trued1=c(trued1,mean((matrix(c(1,xeval[j,]),1,9)%*%matrix(location[1:9])+c(resid*max(matrix(c(1,xeval[j,]),1,9)%*%matrix(location[10:18]),0)^0.5))<=evald[i]))
	if(type==17) for(i in 1:length(evald)) for(j in 1:nrow(xeval)) trued1=c(trued1,mean((matrix(c(1,xeval[j,]),1,9)%*%matrix(location[1:9])+c(resid)*exp(matrix(c(1,xeval[j,]),1,9)%*%matrix(location[10:18]))^0.5)<=evald[i]))
	if(type==4 | type==6 | type==8 | type==10 | type==12 | type==14){
		trued1=rep(NA,length(evald)*nrow(xeval))
		for(i in 1:nrow(xeval)){
			xb=xeval[rep(i,100000),]
			yb=dgp(100000,type,xb,p)
			for(j in 1:length(evald)) trued1[i+neval*(j-1)]=mean(yb<=evald[j])
		}
	}
	if(type==13 | type==15 | type==16){
		yb=yb[(ceiling(length(yb)*(1-p))+1):length(yb)]
		evald1=sort(unique(yb))
		temp=matrix(,length(evald1),neval)
		for(i in 1:length(evald1)) for(j in 1:nrow(xeval)) temp[i,j]=mean((matrix(c(1,xeval[j,]),1,9)%*%matrix(location[1:9])+c(resid*max(matrix(c(1,xeval[j,]),1,9)%*%matrix(location[10:18]),0)^0.5))<=evald1[i])
		for(i in 1:length(evald))  for(j in 1:nrow(xeval)) trued1=c(trued1,((1-p)*mean((matrix(c(1,xeval[j,]),1,9)%*%matrix(location[1:9])+c(resid*max(matrix(c(1,xeval[j,]),1,9)%*%matrix(location[10:18]),0)^0.5))<=evald[i])+p*temp[sum(evald1<=evald[i]),j]))
	}
	if(type==18){
		yb=yb[(ceiling(length(yb)*(1-p))+1):length(yb)]
		evald1=sort(unique(yb))
		temp=matrix(,length(evald1),neval)
		for(i in 1:length(evald1)) for(j in 1:nrow(xeval)) temp[i,j]=mean((matrix(c(1,xeval[j,]),1,9)%*%matrix(location[1:9])+c(resid)*exp(matrix(c(1,xeval[j,]),1,9)%*%matrix(location[10:18]))^0.5)<=evald1[i])
		for(i in 1:length(evald))  for(j in 1:nrow(xeval)) trued1=c(trued1,((1-p)*mean((matrix(c(1,xeval[j,]),1,9)%*%matrix(location[1:9])+c(resid)*exp(matrix(c(1,xeval[j,]),1,9)%*%matrix(location[10:18]))^0.5)<=evald[i])+p*temp[sum(evald1<=evald[i]),j]))
	}
	w1=c(trued1[(neval+1):(neval*length(evald))],rep(1,neval))-trued1
	xb=x_uncond[ceiling(nrow(x_uncond) * runif(1000000)),]
	yb=dgp(1000000,type,xb,p)
	u_trued1=c()
	for(i in 1:length(evald)) u_trued1=c(u_trued1,mean(yb<=evald[i]))
	uw1=c(u_trued1[2:length(u_trued1)],1)-u_trued1
	list(evald=evald,estimd=estimd,index=index,utrue=u_trued1,ctrue=trued1,w=w1,uw=uw1)
}

#Estimation command
estim=function(r,obs,type,p=0.5){
	neval=nrow(xeval)
	obs_pop=nrow(x)
	evald=true$evald
	estimd=true$estimd
	index=true$index
	utrue=true$utrue
	ctrue=true$ctrue
	w=true$w
	uw=true$uw
	set.seed(r)
	xb=x[ceiling(nrow(x) * runif(obs)),]
	yb=dgp(obs,type,xb,p)
	xb_uncond=x_uncond[ceiling(nrow(x_uncond) * runif(obs)),]
	fittedqr=matrix(,obs,nq)
	fittedlog=fittedlog_s=matrix(,obs,length(estimd))
	fitevalqr=matrix(,neval,nq)
	fitevallog=fitevallog_s=matrix(,neval,length(estimd))
	for(q in 1:nq){
		rm(temp)
		try(temp<-rq.fit.fnb(cbind(1,xb), yb, tau=(q/nq-0.5/nq))[[1]],TRUE)
		if(exists("temp")==0) temp<-rq.fit.br(cbind(1,xb), yb, tau=(q/nq-0.5/nq))[[1]]
		if(max(is.na(temp))==1) temp<-rq.fit.br(cbind(1,xb), yb, tau=(q/nq-0.5/nq))[[1]]
		fittedqr[,q]=cbind(1,xb_uncond)%*%temp
		fitevalqr[,q]=cbind(1,xeval)%*%temp
	}
	for(q in 1:length(estimd)){	
		temp=glm(yb<=estimd[q]~xb,family=binomial(link=logit))$coef
		fittedlog[,q]=plogis(cbind(1,xb_uncond)%*%temp)
		fitevallog[,q]=plogis(cbind(1,xeval)%*%temp)
	}
	for(i in 1:obs) fittedlog_s[i,]=sort(fittedlog[i,])
	for(i in 1:neval) fitevallog_s[i,]=sort(fitevallog[i,])
	temp=matrix(,1,3*length(evald))
	for(q in 1:length(evald)) {
		temp[q]=mean(fittedlog[,index[q]])
		temp[q+length(evald)]=mean(fittedlog_s[,index[q]])
		temp[q+2*length(evald)]=mean(fittedqr<=evald[q])
	}
	results=c(mean((temp[1:length(utrue)]-utrue)^2*uw),mean((temp[(length(utrue)+1):(2*length(utrue))]-utrue)^2*uw),mean((temp[(2*length(utrue)+1):(3*length(utrue))]-utrue)^2*uw))
	results=c(results,mean((temp[1:length(utrue)]-utrue)^2*uw/utrue/(1-utrue)),mean((temp[(length(utrue)+1):(2*length(utrue))]-utrue)^2*uw/utrue/(1-utrue)),mean((temp[(2*length(utrue)+1):(3*length(utrue))]-utrue)^2*uw/utrue/(1-utrue)))
	temp=matrix(,1,3*length(ctrue))
	for(q in 1:length(evald)){
		temp[((q-1)*neval+1):(q*neval)]=fitevallog[,index[q]]
		temp[(neval*length(evald)+(q-1)*neval+1):(neval*length(evald)+q*neval)]=fitevallog_s[,index[q]]
		for(i in 1:neval) temp[neval*length(evald)*2+(q-1)*neval+i]=sum(fitevalqr[i,]<=evald[q])/nq	
	}
	results=c(results,mean((temp[1:(length(evald)*neval)]-ctrue)^2*w),mean((temp[(length(evald)*neval+1):(2*length(evald)*neval)]-ctrue)^2*w),mean((temp[(2*length(evald)*neval+1):(3*length(evald)*neval)]-ctrue)^2*w))
	c(results,mean(((temp[1:(length(evald)*neval)]-ctrue)^2*w/ctrue/(1-ctrue))[ctrue>0.001 & ctrue<0.999]),mean(((temp[(length(evald)*neval+1):(2*length(evald)*neval)]-ctrue)^2*w/ctrue/(1-ctrue))[ctrue>0.001 & ctrue<0.999]),mean(((temp[(2*length(evald)*neval+1):(3*length(evald)*neval)]-ctrue)^2*w/ctrue/(1-ctrue))[ctrue>0.001 & ctrue<0.999]))
}

#Figure B1
uv=sort(unique(y))
nuv=c()
for(i in 1:length(uv)) nuv=c(nuv,sum(y==uv[i]))
temp=sort(nuv/sum(nuv),TRUE)[1:25]
xb=x[ceiling(nrow(x) * runif(100000)),]
location=lm(y~x,weights=w)$coef
location=c(sqrt(wt.var(lm(y~x,weights=w)$resid)),location)
yb=dgp(100000,1,xb,p=1/3)
uv=sort(unique(yb))
nuv=c()
for(i in 1:length(uv)) nuv=c(nuv,sum(yb==uv[i]))
temp1=sort(nuv/sum(nuv),TRUE)[1:25]
postscript(file = "C:/Users/Blaise/Documents/A_travail/Quantile/process/DFL/Graphs/FigureB1.eps",horizontal=FALSE, onefile = FALSE, paper = "special", height=7, width=7)
par(mar=c(5.1,4.1,2.1,2.1))
barplot(rbind(cumsum(temp),cumsum(temp1)),beside =TRUE,names=1:25,legend.text=c("True data","Artificial data"),args.legend = list(x = 24,y=0.45),xlab="Most frequent values",ylab="Probability that Y takes exactly one of the most frequent values",xpd=TRUE)
box()
dev.off()

#Values where the estimators will be evaluated
neval=1000
set.seed(1234)
obs_pop=length(y)
xeval=x[ceiling(obs_pop * runif(neval)),]
nq=500
evalq=seq(0.005,0.995,0.01)

#Use a cluster - set number of nodes 
cl <- makeCluster(2)
clusterEvalQ(cl,library(quantreg))
clusterExport(cl,"x")
clusterExport(cl,"x_uncond")
clusterExport(cl,"xeval")
clusterExport(cl,"nq")
clusterExport(cl,"dgp")

#dgp 1: no rounding, iid logistic error
location=lm(y~x,weights=w)$coef
location=c(sqrt(wt.var(lm(y~x,weights=w)$resid)),location)
clusterExport(cl,"location")
true=true_value(0,nq,xeval)
clusterExport(cl,"true")
res0_100=clusterApplyLB(cl, 1:1000, estim, 100, 0)
res0_1000=clusterApplyLB(cl, 1:1000, estim, 1000, 0)
res0_10000=clusterApplyLB(cl, 1:1000, estim, 10000, 0)

#dgp 1: rounding, iid logistic error
true=true_value(1,nq,xeval, p=1/3)
clusterExport(cl,"true")
res1_100=clusterApplyLB(cl, 1:1000, estim, 100, 1, p=1/3)
res1_1000=clusterApplyLB(cl, 1:1000, estim, 1000, 1, p=1/3)
res1_10000=clusterApplyLB(cl, 1:1000, estim, 10000, 1, p=1/3)

#Table B1 and B2
tableb1=matrix(,6,6)
tableb2=matrix(,6,6)
l=1
for(i in c("res0_100","res0_1000","res0_10000")){
	temp_mean=rep(0,12)
	reps=length(get(i))
	for(r in 1:1000) temp_mean=temp_mean+get(i)[[r]]/reps
	tableb1[l,1:3]=temp_mean[1:3]
	tableb1[l+3,1:3]=temp_mean[7:9]
	tableb2[l,1:3]=temp_mean[4:6]
	tableb2[l+3,1:3]=temp_mean[10:12]
	l=l+1
}
l=1
for(i in c("res1_100","res1_1000","res1_10000")){
	temp_mean=rep(0,12)
	reps=length(get(i))
	for(r in 1:1000) temp_mean=temp_mean+get(i)[[r]]/reps
	tableb1[l,4:6]=temp_mean[1:3]
	tableb1[l+3,4:6]=temp_mean[7:9]
	tableb2[l,4:6]=temp_mean[4:6]
	tableb2[l+3,4:6]=temp_mean[10:12]
	l=l+1
}
round(1000*sqrt(tableb1),2)
round(1000*sqrt(tableb2),2)

#dgp 2: no rounding, iid empirical residuals distribution
location=lm(y~x,weights=w)$coef
resid=y-cbind(1,x)%*%location
clusterExport(cl,"location")
clusterExport(cl,"resid")
true=true_value(9,nq,xeval)
clusterExport(cl,"true")
res9_100=clusterApplyLB(cl, 1:1000, estim, 100, 9)
res9_1000=clusterApplyLB(cl, 1:1000, estim, 1000, 9)
res9_10000=clusterApplyLB(cl, 1:1000, estim, 10000, 9)

#dgp 2: rounding, iid empirical residuals distribution
true=true_value(14,nq,xeval,p=1/3)
clusterExport(cl,"true")
res14_100=clusterApplyLB(cl, 1:1000, estim, 100, 14, p=1/3)
res14_1000=clusterApplyLB(cl, 1:1000, estim, 1000, 14, p=1/3)
res14_10000=clusterApplyLB(cl, 1:100, estim, 10000, 14, p=1/3)

#Table B3 and B4
tableb3=matrix(,6,6)
tableb4=matrix(,6,6)
l=1
for(i in c("res9_100","res9_1000","res9_10000")){
	temp_mean=rep(0,12)
	reps=length(get(i))
	for(r in 1:1000) temp_mean=temp_mean+get(i)[[r]]/reps
	tableb3[l,1:3]=temp_mean[1:3]
	tableb3[l+3,1:3]=temp_mean[7:9]
	tableb4[l,1:3]=temp_mean[4:6]
	tableb4[l+3,1:3]=temp_mean[10:12]
	l=l+1
}
l=1
for(i in c("res14_100","res14_1000","res14_10000")){
	temp_mean=rep(0,12)
	reps=length(get(i))
	for(r in 1:1000) temp_mean=temp_mean+get(i)[[r]]/reps
	tableb3[l,4:6]=temp_mean[1:3]
	tableb3[l+3,4:6]=temp_mean[7:9]
	tableb4[l,4:6]=temp_mean[4:6]
	tableb4[l+3,4:6]=temp_mean[10:12]
	l=l+1
}
round(1000*sqrt(tableb3),2)
round(1000*sqrt(tableb4),2)

#dgp 3: no rounding, heteroscedastic
location=lm(y~x,weights=w)$coef
resid=y-cbind(1,x)%*%location
location=c(location,lm(resid^2~x,weights=w)$coef)
resid=resid/pmax(cbind(1,x)%*%location[10:18],0.00001)^0.5
clusterExport(cl,"location")
clusterExport(cl,"resid")

true=true_value(11,nq,xeval)
clusterExport(cl,"true")
res11_100=clusterApplyLB(cl, 1:500, estim, 100, 11)
res11_1000=clusterApplyLB(cl, 1:250, estim, 1000, 11)
res11_10000=clusterApplyLB(cl, 1:100, estim, 10000, 11)

#dgp 3: rounding, heteroscedastic
true=true_value(15,nq,xeval, p=1/3)
clusterExport(cl,"true")
res15_100=clusterApplyLB(cl, 1:100, estim, 100, 15, p=1/3)
res15_1000=clusterApplyLB(cl, 1:250, estim, 1000, 15, p=1/3)
res15_10000=clusterApplyLB(cl, 1:10, estim, 10000, 15, p=1/3)

#Table B5 and B6
tableb5=matrix(,6,6)
tableb6=matrix(,6,6)
l=1
for(i in c("res11_100","res11_1000","res11_10000")){
	temp_mean=rep(0,12)
	reps=length(get(i))
	for(r in 1:1000) temp_mean=temp_mean+get(i)[[r]]/reps
	tableb5[l,1:3]=temp_mean[1:3]
	tableb5[l+3,1:3]=temp_mean[7:9]
	tableb6[l,1:3]=temp_mean[4:6]
	tableb6[l+3,1:3]=temp_mean[10:12]
	l=l+1
}
l=1
for(i in c("res15_100","res15_1000","res15_10000")){
	temp_mean=rep(0,12)
	reps=length(get(i))
	for(r in 1:1000) temp_mean=temp_mean+get(i)[[r]]/reps
	tableb5[l,4:6]=temp_mean[1:3]
	tableb5[l+3,4:6]=temp_mean[7:9]
	tableb6[l,4:6]=temp_mean[4:6]
	tableb6[l+3,4:6]=temp_mean[10:12]
	l=l+1
}
round(1000*sqrt(tableb5),2)
round(1000*sqrt(tableb6),2)


